///
/// @file  pre_sieve.hpp
/// @brief Static pre-sieved lookup tables from which the primes and
///        multiples of primes ≤ 71 have been removed upfront. These
///        arrays are bitwise AND'ed into the sieve array by
///        pre_sieve.cpp to quickly remove the small primes and their
///        multiples from the sieve.
///
/// Copyright (C) 2026 Kim Walisch, <kim.walisch@gmail.com>
///
/// This file is distributed under the BSD License. See the COPYING
/// file in the top level directory.
///

#ifndef PRE_SIEVE_HPP
#define PRE_SIEVE_HPP

#include <Vector.hpp>

#include <stdint.h>
#include <initializer_list>

namespace {

/// Static array from which the primes and multiples
/// of primes ≤ 13 have been removed.
///
const primecount::Array<uint8_t, 4004> pre_sieved_13 =
{
  0xf1, 0xdf, 0xef, 0x7e, 0xb6, 0xdb, 0x3d, 0xf9, 0xd5, 0x6f, 0x5e, 0xf3, 0xeb, 0xa7, 0xfd, 0x9e, 0xee, 0x3c, 0xd7, 0xf3,
  0xbb, 0xdd, 0x5b, 0xef, 0x6e, 0xe7, 0xb2, 0xbf, 0x7d, 0xde, 0xa7, 0x5e, 0xd7, 0xfb, 0xbd, 0x6d, 0xdf, 0xae, 0x6e, 0x75,
  0xfb, 0xb7, 0xfc, 0x9f, 0xcb, 0x7e, 0xe3, 0xf9, 0x3e, 0xfd, 0x5d, 0xef, 0x76, 0xf7, 0xdb, 0xba, 0xbd, 0xcf, 0xef, 0x3a,
  0xf5, 0x79, 0xbf, 0xf5, 0xcf, 0xc7, 0x7a, 0xf7, 0xea, 0xbf, 0x9c, 0xdf, 0x69, 0x7c, 0x77, 0xfb, 0x9f, 0xe9, 0xd7, 0xef,
  0x7e, 0xb6, 0xbb, 0x1d, 0xfd, 0xd3, 0xed, 0x5e, 0xf3, 0xfb, 0xaf, 0xf5, 0x9e, 0xef, 0x7c, 0xb7, 0xd3, 0xbf, 0xd9, 0xd9,
  0x6f, 0x6e, 0xf7, 0xaa, 0xb7, 0x7d, 0xdf, 0xe6, 0x3e, 0xd7, 0xfb, 0xbb, 0xed, 0x5f, 0xae, 0x7e, 0x65, 0xf3, 0xb7, 0xfd,
  0xde, 0xab, 0x5e, 0xe7, 0xfb, 0xbc, 0x7d, 0x5d, 0xef, 0x66, 0xf7, 0xdb, 0xbb, 0xfc, 0x8f, 0xcf, 0x3e, 0xf3, 0x79, 0x3f,
  0xf5, 0xdf, 0xcf, 0x72, 0xf7, 0xeb, 0xbe, 0xbc, 0xdf, 0x6d, 0x7a, 0xf5, 0x7b, 0x9f, 0xf9, 0xcf, 0xe7, 0x7e, 0xb6, 0xfa,
  0x3d, 0xdd, 0xd7, 0xeb, 0x5c, 0x73, 0xfb, 0xaf, 0xed, 0x96, 0xef, 0x7c, 0xf6, 0xb3, 0x9f, 0xdd, 0xdb, 0xed, 0x6e, 0xf7,
  0xba, 0xaf, 0x75, 0xdf, 0xe7, 0x7e, 0x97, 0xdb, 0xbf, 0xe9, 0xdd, 0x2e, 0x7e, 0x75, 0xeb, 0xb7, 0xfd, 0xdf, 0xea, 0x3e,
  0xc7, 0xfb, 0xba, 0xfd, 0x5d, 0xef, 0x76, 0xe7, 0xd3, 0xbb, 0xfd, 0xce, 0xaf, 0x1e, 0xf7, 0x79, 0xbd, 0x75, 0xdf, 0xcf,
  0x6a, 0xf7, 0xeb, 0xbf, 0xbc, 0x9f, 0x4d, 0x7e, 0xf3, 0xf9, 0x1f, 0xf9, 0xdf, 0xef, 0x76, 0xb6, 0xfb, 0x3c, 0xbd, 0xd7,
  0xef, 0x5a, 0xf1, 0x7b, 0xaf, 0xfd, 0x8e, 0xe7, 0x7c, 0xf7, 0xf2, 0xbf, 0xdd, 0xdb, 0xeb, 0x6c, 0x77, 0xba, 0xbf, 0x6d,
  0xd7, 0xe7, 0x7e, 0xd6, 0xbb, 0x9f, 0xed, 0xdb, 0xac, 0x7e, 0x75, 0xfb, 0xa7, 0xf5, 0xdf, 0xeb, 0x7e, 0xa7, 0xdb, 0xbe,
  0xf9, 0x5d, 0x6f, 0x76, 0xf7, 0xcb, 0xb3, 0xfd, 0xcf, 0xee, 0x3e, 0xd7, 0x79, 0xbb, 0xf5, 0x5f, 0xcf, 0x7a, 0xe7, 0xe3,
  0xbf, 0xbc, 0xde, 0x2d, 0x5e, 0xf7, 0xfb, 0x9d, 0x79, 0xdf, 0xef, 0x6e, 0xb6, 0xfb, 0x3d, 0xfc, 0x97, 0xcf, 0x5e, 0xf3,
  0xf9, 0x2f, 0xfd, 0x9e, 0xef, 0x74, 0xf7, 0xf3, 0xbe, 0x9d, 0xdb, 0xef, 0x6a, 0xf5, 0x3a, 0xbf, 0x7d, 0xcf, 0xe7, 0x7e,
  0xd7, 0xfa, 0xbf, 0xcd, 0xdf, 0xaa, 0x7c, 0x75, 0xfb, 0xb7, 0xed, 0xd7, 0xeb, 0x7e, 0xe6, 0xbb, 0x9e, 0xfd, 0x59, 0xed,
  0x76, 0xf7, 0xdb, 0xab, 0xf5, 0xcf, 0xef, 0x3e, 0xb7, 0x59, 0xbf, 0xf1, 0xdd, 0x4f, 0x7a, 0xf7, 0xeb, 0xb7, 0xbc, 0xdf,
  0x6c, 0x3e, 0xd7, 0xfb, 0x9b, 0xf9, 0x5f, 0xef, 0x7e, 0xa6, 0xf3, 0x3d, 0xfd, 0xd6, 0xaf, 0x5e, 0xf3, 0xfb, 0xad, 0x7d,
  0x9e, 0xef, 0x6c, 0xf7, 0xf3, 0xbf, 0xdc, 0x9b, 0xcf, 0x6e, 0xf3, 0xb8, 0x3f, 0x7d, 0xdf, 0xe7, 0x76, 0xd7, 0xfb, 0xbe,
  0xad, 0xdf, 0xae, 0x7a, 0x75, 0x7b, 0xb7, 0xfd, 0xcf, 0xe3, 0x7e, 0xe7, 0xfa, 0xbe, 0xdd, 0x5d, 0xeb, 0x74, 0x77, 0xdb,
  0xbb, 0xed, 0xc7, 0xef, 0x3e, 0xf6, 0x39, 0x9f, 0xf5, 0xdb, 0xcd, 0x7a, 0xf7, 0xeb, 0xaf, 0xb4, 0xdf, 0x6d, 0x7e, 0xb7,
  0xdb, 0x9f, 0xf9, 0xdd, 0x6f, 0x7e, 0xb6, 0xeb, 0x35, 0xfd, 0xd7, 0xee, 0x1e, 0xd3, 0xfb, 0xab, 0xfd, 0x1e, 0xef, 0x7c,
  0xe7, 0xf3, 0xbf, 0xdd, 0xda, 0xaf, 0x4e, 0xf7, 0xba, 0xbd, 0x7d, 0xdf, 0xe7, 0x6e, 0xd7, 0xfb, 0xbf, 0xec, 0x9f, 0x8e,
  0x7e, 0x71, 0xf9, 0x37, 0xfd, 0xdf, 0xeb, 0x76, 0xe7, 0xfb, 0xbe, 0xbd, 0x5d, 0xef, 0x72, 0xf5, 0x5b, 0xbb, 0xfd, 0xcf,
  0xe7, 0x3e, 0xf7, 0x78, 0xbf, 0xd5, 0xdf, 0xcb, 0x78, 0x77, 0xeb, 0xbf, 0xac, 0xd7, 0x6d, 0x7e, 0xf6, 0xbb, 0x9f, 0xf9,
  0xdb, 0xed, 0x7e, 0xb6, 0xfb, 0x2d, 0xf5, 0xd7, 0xef, 0x5e, 0xb3, 0xdb, 0xaf, 0xf9, 0x9c, 0x6f, 0x7c, 0xf7, 0xe3, 0xb7,
  0xdd, 0xdb, 0xee, 0x2e, 0xd7, 0xba, 0xbb, 0x7d, 0x5f, 0xe7, 0x7e, 0xc7, 0xf3, 0xbf, 0xed, 0xde, 0xae, 0x5e, 0x75, 0xfb,
  0xb5, 0x7d, 0xdf, 0xeb, 0x6e, 0xe7, 0xfb, 0xbe, 0xfc, 0x1d, 0xcf, 0x76, 0xf3, 0xd9, 0x3b, 0xfd, 0xcf, 0xef, 0x36, 0xf7,
  0x79, 0xbe, 0xb5, 0xdf, 0xcf, 0x7a, 0xf5, 0x6b, 0xbf, 0xbc, 0xcf, 0x65, 0x7e, 0xf7, 0xfa, 0x9f, 0xd9, 0xdf, 0xeb, 0x7c,
  0x36, 0xfb, 0x3d, 0xed, 0xd7, 0xef, 0x5e, 0xf2, 0xbb, 0x8f, 0xfd, 0x9a, 0xed, 0x7c, 0xf7, 0xf3, 0xaf, 0xd5, 0xdb, 0xef,
  0x6e, 0xb7, 0x9a, 0xbf, 0x79, 0xdd, 0x67, 0x7e, 0xd7, 0xeb, 0xb7, 0xed, 0xdf, 0xae, 0x3e, 0x55, 0xfb, 0xb3, 0xfd, 0x5f,
  0xeb, 0x7e, 0xe7, 0xf3, 0xbe, 0xfd, 0x5c, 0xaf, 0x56, 0xf7, 0xdb, 0xb9, 0x7d, 0xcf, 0xef, 0x2e, 0xf7, 0x79, 0xbf, 0xf4,
  0x9f, 0xcf, 0x7a, 0xf3, 0xe9, 0x3f, 0xbc, 0xdf, 0x6d, 0x76, 0xf7, 0xfb, 0x9e, 0xb9, 0xdf, 0xef, 0x7a, 0xb4, 0x7b, 0x3d,
  0xfd, 0xc7, 0xe7, 0x5e, 0xf3, 0xfa, 0xaf, 0xdd, 0x9e, 0xeb, 0x7c, 0x77, 0xf3, 0xbf, 0xcd, 0xd3, 0xef, 0x6e, 0xf6, 0xba,
  0x9f, 0x7d, 0xdb, 0xe5, 0x7e, 0xd7, 0xfb, 0xaf, 0xe5, 0xdf, 0xae, 0x7e, 0x35, 0xdb, 0xb7, 0xf9, 0xdd, 0x6b, 0x7e, 0xe7,
  0xeb, 0xb6, 0xfd, 0x5d, 0xee, 0x36, 0xd7, 0xdb, 0xbb, 0xfd, 0x4f, 0xef, 0x3e, 0xe7, 0x71, 0xbf, 0xf5, 0xde, 0x8f, 0x5a,
  0xf7, 0xeb, 0xbd, 0x3c, 0xdf, 0x6d, 0x6e, 0xf7, 0xfb, 0x9f, 0xf8, 0x9f, 0xcf, 0x7e, 0xb2, 0xf9, 0x3d, 0xfd, 0xd7, 0xef,
  0x56, 0xf3, 0xfb, 0xae, 0xbd, 0x9e, 0xef, 0x78, 0xf5, 0x73, 0xbf, 0xdd, 0xcb, 0xe7, 0x6e, 0xf7, 0xba, 0xbf, 0x5d, 0xdf,
  0xe3, 0x7c, 0x57, 0xfb, 0xbf, 0xed, 0xd7, 0xae, 0x7e, 0x74, 0xbb, 0x97, 0xfd, 0xdb, 0xe9, 0x7e, 0xe7, 0xfb, 0xae, 0xf5,
  0x5d, 0xef, 0x76, 0xb7, 0xdb, 0xbb, 0xf9, 0xcd, 0x6f, 0x3e, 0xf7, 0x69, 0xb7, 0xf5, 0xdf, 0xce, 0x3a, 0xd7, 0xeb, 0xbb,
  0xbc, 0x5f, 0x6d, 0x7e, 0xe7, 0xf3, 0x9f, 0xf9, 0xde, 0xaf, 0x5e, 0xb6, 0xfb, 0x3d, 0x7d, 0xd7, 0xef, 0x4e, 0xf3, 0xfb,
  0xaf, 0xfc, 0x9e, 0xcf, 0x7c, 0xf3, 0xf1, 0x3f, 0xdd, 0xdb, 0xef, 0x66, 0xf7, 0xba, 0xbe, 0x3d, 0xdf, 0xe7, 0x7a, 0xd5,
  0x7b, 0xbf, 0xed, 0xcf, 0xa6, 0x7e, 0x75, 0xfa, 0xb7, 0xdd, 0xdf, 0xeb, 0x7c, 0x67, 0xfb, 0xbe, 0xed, 0x55, 0xef, 0x76,
  0xf6, 0x9b, 0x9b, 0xfd, 0xcb, 0xed, 0x3e, 0xf7, 0x79, 0xaf, 0xf5, 0xdf, 0xcf, 0x7a, 0xb7, 0xcb, 0xbf, 0xb8, 0xdd, 0x6d,
  0x7e, 0xf7, 0xeb, 0x97, 0xf9, 0xdf, 0xee, 0x3e, 0x96, 0xfb, 0x39, 0xfd, 0x57, 0xef, 0x5e, 0xe3, 0xf3, 0xaf, 0xfd, 0x9e,
  0xaf, 0x5c, 0xf7, 0xf3, 0xbd, 0x5d, 0xdb, 0xef, 0x6e, 0xf7, 0xba, 0xbf, 0x7c, 0x9f, 0xc7, 0x7e, 0xd3, 0xf9, 0x3f, 0xed,
  0xdf, 0xae, 0x76, 0x75, 0xfb, 0xb6, 0xbd, 0xdf, 0xeb, 0x7a, 0xe5, 0x7b, 0xbe, 0xfd, 0x4d, 0xe7, 0x76, 0xf7, 0xda, 0xbb,
  0xdd, 0xcf, 0xeb, 0x3c, 0x77, 0x79, 0xbf, 0xe5, 0xd7, 0xcf, 0x7a, 0xf6, 0xab, 0x9f, 0xbc, 0xdb, 0x6d, 0x7e, 0xf7, 0xfb,
  0x8f, 0xf1, 0xdf, 0xef, 0x7e, 0xb6, 0xdb, 0x3d, 0xf9, 0xd5, 0x6f, 0x5e, 0xf3, 0xeb, 0xa7, 0xfd, 0x9e, 0xee, 0x3c, 0xd7,
  0xf3, 0xbb, 0xdd, 0x5b, 0xef, 0x6e, 0xe7, 0xb2, 0xbf, 0x7d, 0xde, 0xa7, 0x5e, 0xd7, 0xfb, 0xbd, 0x6d, 0xdf, 0xae, 0x6e,
  0x75, 0xfb, 0xb7, 0xfc, 0x9f, 0xcb, 0x7e, 0xe3, 0xf9, 0x3e, 0xfd, 0x5d, 0xef, 0x76, 0xf7, 0xdb, 0xba, 0xbd, 0xcf, 0xef,
  0x3a, 0xf5, 0x79, 0xbf, 0xf5, 0xcf, 0xc7, 0x7a, 0xf7, 0xea, 0xbf, 0x9c, 0xdf, 0x69, 0x7c, 0x77, 0xfb, 0x9f, 0xe9, 0xd7,
  0xef, 0x7e, 0xb6, 0xbb, 0x1d, 0xfd, 0xd3, 0xed, 0x5e, 0xf3, 0xfb, 0xaf, 0xf5, 0x9e, 0xef, 0x7c, 0xb7, 0xd3, 0xbf, 0xd9,
  0xd9, 0x6f, 0x6e, 0xf7, 0xaa, 0xb7, 0x7d, 0xdf, 0xe6, 0x3e, 0xd7, 0xfb, 0xbb, 0xed, 0x5f, 0xae, 0x7e, 0x65, 0xf3, 0xb7,
  0xfd, 0xde, 0xab, 0x5e, 0xe7, 0xfb, 0xbc, 0x7d, 0x5d, 0xef, 0x66, 0xf7, 0xdb, 0xbb, 0xfc, 0x8f, 0xcf, 0x3e, 0xf3, 0x79,
  0x3f, 0xf5, 0xdf, 0xcf, 0x72, 0xf7, 0xeb, 0xbe, 0xbc, 0xdf, 0x6d, 0x7a, 0xf5, 0x7b, 0x9f, 0xf9, 0xcf, 0xe7, 0x7e, 0xb6,
  0xfa, 0x3d, 0xdd, 0xd7, 0xeb, 0x5c, 0x73, 0xfb, 0xaf, 0xed, 0x96, 0xef, 0x7c, 0xf6, 0xb3, 0x9f, 0xdd, 0xdb, 0xed, 0x6e,
  0xf7, 0xba, 0xaf, 0x75, 0xdf, 0xe7, 0x7e, 0x97, 0xdb, 0xbf, 0xe9, 0xdd, 0x2e, 0x7e, 0x75, 0xeb, 0xb7, 0xfd, 0xdf, 0xea,
  0x3e, 0xc7, 0xfb, 0xba, 0xfd, 0x5d, 0xef, 0x76, 0xe7, 0xd3, 0xbb, 0xfd, 0xce, 0xaf, 0x1e, 0xf7, 0x79, 0xbd, 0x75, 0xdf,
  0xcf, 0x6a, 0xf7, 0xeb, 0xbf, 0xbc, 0x9f, 0x4d, 0x7e, 0xf3, 0xf9, 0x1f, 0xf9, 0xdf, 0xef, 0x76, 0xb6, 0xfb, 0x3c, 0xbd,
  0xd7, 0xef, 0x5a, 0xf1, 0x7b, 0xaf, 0xfd, 0x8e, 0xe7, 0x7c, 0xf7, 0xf2, 0xbf, 0xdd, 0xdb, 0xeb, 0x6c, 0x77, 0xba, 0xbf,
  0x6d, 0xd7, 0xe7, 0x7e, 0xd6, 0xbb, 0x9f, 0xed, 0xdb, 0xac, 0x7e, 0x75, 0xfb, 0xa7, 0xf5, 0xdf, 0xeb, 0x7e, 0xa7, 0xdb,
  0xbe, 0xf9, 0x5d, 0x6f, 0x76, 0xf7, 0xcb, 0xb3, 0xfd, 0xcf, 0xee, 0x3e, 0xd7, 0x79, 0xbb, 0xf5, 0x5f, 0xcf, 0x7a, 0xe7,
  0xe3, 0xbf, 0xbc, 0xde, 0x2d, 0x5e, 0xf7, 0xfb, 0x9d, 0x79, 0xdf, 0xef, 0x6e, 0xb6, 0xfb, 0x3d, 0xfc, 0x97, 0xcf, 0x5e,
  0xf3, 0xf9, 0x2f, 0xfd, 0x9e, 0xef, 0x74, 0xf7, 0xf3, 0xbe, 0x9d, 0xdb, 0xef, 0x6a, 0xf5, 0x3a, 0xbf, 0x7d, 0xcf, 0xe7,
  0x7e, 0xd7, 0xfa, 0xbf, 0xcd, 0xdf, 0xaa, 0x7c, 0x75, 0xfb, 0xb7, 0xed, 0xd7, 0xeb, 0x7e, 0xe6, 0xbb, 0x9e, 0xfd, 0x59,
  0xed, 0x76, 0xf7, 0xdb, 0xab, 0xf5, 0xcf, 0xef, 0x3e, 0xb7, 0x59, 0xbf, 0xf1, 0xdd, 0x4f, 0x7a, 0xf7, 0xeb, 0xb7, 0xbc,
  0xdf, 0x6c, 0x3e, 0xd7, 0xfb, 0x9b, 0xf9, 0x5f, 0xef, 0x7e, 0xa6, 0xf3, 0x3d, 0xfd, 0xd6, 0xaf, 0x5e, 0xf3, 0xfb, 0xad,
  0x7d, 0x9e, 0xef, 0x6c, 0xf7, 0xf3, 0xbf, 0xdc, 0x9b, 0xcf, 0x6e, 0xf3, 0xb8, 0x3f, 0x7d, 0xdf, 0xe7, 0x76, 0xd7, 0xfb,
  0xbe, 0xad, 0xdf, 0xae, 0x7a, 0x75, 0x7b, 0xb7, 0xfd, 0xcf, 0xe3, 0x7e, 0xe7, 0xfa, 0xbe, 0xdd, 0x5d, 0xeb, 0x74, 0x77,
  0xdb, 0xbb, 0xed, 0xc7, 0xef, 0x3e, 0xf6, 0x39, 0x9f, 0xf5, 0xdb, 0xcd, 0x7a, 0xf7, 0xeb, 0xaf, 0xb4, 0xdf, 0x6d, 0x7e,
  0xb7, 0xdb, 0x9f, 0xf9, 0xdd, 0x6f, 0x7e, 0xb6, 0xeb, 0x35, 0xfd, 0xd7, 0xee, 0x1e, 0xd3, 0xfb, 0xab, 0xfd, 0x1e, 0xef,
  0x7c, 0xe7, 0xf3, 0xbf, 0xdd, 0xda, 0xaf, 0x4e, 0xf7, 0xba, 0xbd, 0x7d, 0xdf, 0xe7, 0x6e, 0xd7, 0xfb, 0xbf, 0xec, 0x9f,
  0x8e, 0x7e, 0x71, 0xf9, 0x37, 0xfd, 0xdf, 0xeb, 0x76, 0xe7, 0xfb, 0xbe, 0xbd, 0x5d, 0xef, 0x72, 0xf5, 0x5b, 0xbb, 0xfd,
  0xcf, 0xe7, 0x3e, 0xf7, 0x78, 0xbf, 0xd5, 0xdf, 0xcb, 0x78, 0x77, 0xeb, 0xbf, 0xac, 0xd7, 0x6d, 0x7e, 0xf6, 0xbb, 0x9f,
  0xf9, 0xdb, 0xed, 0x7e, 0xb6, 0xfb, 0x2d, 0xf5, 0xd7, 0xef, 0x5e, 0xb3, 0xdb, 0xaf, 0xf9, 0x9c, 0x6f, 0x7c, 0xf7, 0xe3,
  0xb7, 0xdd, 0xdb, 0xee, 0x2e, 0xd7, 0xba, 0xbb, 0x7d, 0x5f, 0xe7, 0x7e, 0xc7, 0xf3, 0xbf, 0xed, 0xde, 0xae, 0x5e, 0x75,
  0xfb, 0xb5, 0x7d, 0xdf, 0xeb, 0x6e, 0xe7, 0xfb, 0xbe, 0xfc, 0x1d, 0xcf, 0x76, 0xf3, 0xd9, 0x3b, 0xfd, 0xcf, 0xef, 0x36,
  0xf7, 0x79, 0xbe, 0xb5, 0xdf, 0xcf, 0x7a, 0xf5, 0x6b, 0xbf, 0xbc, 0xcf, 0x65, 0x7e, 0xf7, 0xfa, 0x9f, 0xd9, 0xdf, 0xeb,
  0x7c, 0x36, 0xfb, 0x3d, 0xed, 0xd7, 0xef, 0x5e, 0xf2, 0xbb, 0x8f, 0xfd, 0x9a, 0xed, 0x7c, 0xf7, 0xf3, 0xaf, 0xd5, 0xdb,
  0xef, 0x6e, 0xb7, 0x9a, 0xbf, 0x79, 0xdd, 0x67, 0x7e, 0xd7, 0xeb, 0xb7, 0xed, 0xdf, 0xae, 0x3e, 0x55, 0xfb, 0xb3, 0xfd,
  0x5f, 0xeb, 0x7e, 0xe7, 0xf3, 0xbe, 0xfd, 0x5c, 0xaf, 0x56, 0xf7, 0xdb, 0xb9, 0x7d, 0xcf, 0xef, 0x2e, 0xf7, 0x79, 0xbf,
  0xf4, 0x9f, 0xcf, 0x7a, 0xf3, 0xe9, 0x3f, 0xbc, 0xdf, 0x6d, 0x76, 0xf7, 0xfb, 0x9e, 0xb9, 0xdf, 0xef, 0x7a, 0xb4, 0x7b,
  0x3d, 0xfd, 0xc7, 0xe7, 0x5e, 0xf3, 0xfa, 0xaf, 0xdd, 0x9e, 0xeb, 0x7c, 0x77, 0xf3, 0xbf, 0xcd, 0xd3, 0xef, 0x6e, 0xf6,
  0xba, 0x9f, 0x7d, 0xdb, 0xe5, 0x7e, 0xd7, 0xfb, 0xaf, 0xe5, 0xdf, 0xae, 0x7e, 0x35, 0xdb, 0xb7, 0xf9, 0xdd, 0x6b, 0x7e,
  0xe7, 0xeb, 0xb6, 0xfd, 0x5d, 0xee, 0x36, 0xd7, 0xdb, 0xbb, 0xfd, 0x4f, 0xef, 0x3e, 0xe7, 0x71, 0xbf, 0xf5, 0xde, 0x8f,
  0x5a, 0xf7, 0xeb, 0xbd, 0x3c, 0xdf, 0x6d, 0x6e, 0xf7, 0xfb, 0x9f, 0xf8, 0x9f, 0xcf, 0x7e, 0xb2, 0xf9, 0x3d, 0xfd, 0xd7,
  0xef, 0x56, 0xf3, 0xfb, 0xae, 0xbd, 0x9e, 0xef, 0x78, 0xf5, 0x73, 0xbf, 0xdd, 0xcb, 0xe7, 0x6e, 0xf7, 0xba, 0xbf, 0x5d,
  0xdf, 0xe3, 0x7c, 0x57, 0xfb, 0xbf, 0xed, 0xd7, 0xae, 0x7e, 0x74, 0xbb, 0x97, 0xfd, 0xdb, 0xe9, 0x7e, 0xe7, 0xfb, 0xae,
  0xf5, 0x5d, 0xef, 0x76, 0xb7, 0xdb, 0xbb, 0xf9, 0xcd, 0x6f, 0x3e, 0xf7, 0x69, 0xb7, 0xf5, 0xdf, 0xce, 0x3a, 0xd7, 0xeb,
  0xbb, 0xbc, 0x5f, 0x6d, 0x7e, 0xe7, 0xf3, 0x9f, 0xf9, 0xde, 0xaf, 0x5e, 0xb6, 0xfb, 0x3d, 0x7d, 0xd7, 0xef, 0x4e, 0xf3,
  0xfb, 0xaf, 0xfc, 0x9e, 0xcf, 0x7c, 0xf3, 0xf1, 0x3f, 0xdd, 0xdb, 0xef, 0x66, 0xf7, 0xba, 0xbe, 0x3d, 0xdf, 0xe7, 0x7a,
  0xd5, 0x7b, 0xbf, 0xed, 0xcf, 0xa6, 0x7e, 0x75, 0xfa, 0xb7, 0xdd, 0xdf, 0xeb, 0x7c, 0x67, 0xfb, 0xbe, 0xed, 0x55, 0xef,
  0x76, 0xf6, 0x9b, 0x9b, 0xfd, 0xcb, 0xed, 0x3e, 0xf7, 0x79, 0xaf, 0xf5, 0xdf, 0xcf, 0x7a, 0xb7, 0xcb, 0xbf, 0xb8, 0xdd,
  0x6d, 0x7e, 0xf7, 0xeb, 0x97, 0xf9, 0xdf, 0xee, 0x3e, 0x96, 0xfb, 0x39, 0xfd, 0x57, 0xef, 0x5e, 0xe3, 0xf3, 0xaf, 0xfd,
  0x9e, 0xaf, 0x5c, 0xf7, 0xf3, 0xbd, 0x5d, 0xdb, 0xef, 0x6e, 0xf7, 0xba, 0xbf, 0x7c, 0x9f, 0xc7, 0x7e, 0xd3, 0xf9, 0x3f,
  0xed, 0xdf, 0xae, 0x76, 0x75, 0xfb, 0xb6, 0xbd, 0xdf, 0xeb, 0x7a, 0xe5, 0x7b, 0xbe, 0xfd, 0x4d, 0xe7, 0x76, 0xf7, 0xda,
  0xbb, 0xdd, 0xcf, 0xeb, 0x3c, 0x77, 0x79, 0xbf, 0xe5, 0xd7, 0xcf, 0x7a, 0xf6, 0xab, 0x9f, 0xbc, 0xdb, 0x6d, 0x7e, 0xf7,
  0xfb, 0x8f, 0xf1, 0xdf, 0xef, 0x7e, 0xb6, 0xdb, 0x3d, 0xf9, 0xd5, 0x6f, 0x5e, 0xf3, 0xeb, 0xa7, 0xfd, 0x9e, 0xee, 0x3c,
  0xd7, 0xf3, 0xbb, 0xdd, 0x5b, 0xef, 0x6e, 0xe7, 0xb2, 0xbf, 0x7d, 0xde, 0xa7, 0x5e, 0xd7, 0xfb, 0xbd, 0x6d, 0xdf, 0xae,
  0x6e, 0x75, 0xfb, 0xb7, 0xfc, 0x9f, 0xcb, 0x7e, 0xe3, 0xf9, 0x3e, 0xfd, 0x5d, 0xef, 0x76, 0xf7, 0xdb, 0xba, 0xbd, 0xcf,
  0xef, 0x3a, 0xf5, 0x79, 0xbf, 0xf5, 0xcf, 0xc7, 0x7a, 0xf7, 0xea, 0xbf, 0x9c, 0xdf, 0x69, 0x7c, 0x77, 0xfb, 0x9f, 0xe9,
  0xd7, 0xef, 0x7e, 0xb6, 0xbb, 0x1d, 0xfd, 0xd3, 0xed, 0x5e, 0xf3, 0xfb, 0xaf, 0xf5, 0x9e, 0xef, 0x7c, 0xb7, 0xd3, 0xbf,
  0xd9, 0xd9, 0x6f, 0x6e, 0xf7, 0xaa, 0xb7, 0x7d, 0xdf, 0xe6, 0x3e, 0xd7, 0xfb, 0xbb, 0xed, 0x5f, 0xae, 0x7e, 0x65, 0xf3,
  0xb7, 0xfd, 0xde, 0xab, 0x5e, 0xe7, 0xfb, 0xbc, 0x7d, 0x5d, 0xef, 0x66, 0xf7, 0xdb, 0xbb, 0xfc, 0x8f, 0xcf, 0x3e, 0xf3,
  0x79, 0x3f, 0xf5, 0xdf, 0xcf, 0x72, 0xf7, 0xeb, 0xbe, 0xbc, 0xdf, 0x6d, 0x7a, 0xf5, 0x7b, 0x9f, 0xf9, 0xcf, 0xe7, 0x7e,
  0xb6, 0xfa, 0x3d, 0xdd, 0xd7, 0xeb, 0x5c, 0x73, 0xfb, 0xaf, 0xed, 0x96, 0xef, 0x7c, 0xf6, 0xb3, 0x9f, 0xdd, 0xdb, 0xed,
  0x6e, 0xf7, 0xba, 0xaf, 0x75, 0xdf, 0xe7, 0x7e, 0x97, 0xdb, 0xbf, 0xe9, 0xdd, 0x2e, 0x7e, 0x75, 0xeb, 0xb7, 0xfd, 0xdf,
  0xea, 0x3e, 0xc7, 0xfb, 0xba, 0xfd, 0x5d, 0xef, 0x76, 0xe7, 0xd3, 0xbb, 0xfd, 0xce, 0xaf, 0x1e, 0xf7, 0x79, 0xbd, 0x75,
  0xdf, 0xcf, 0x6a, 0xf7, 0xeb, 0xbf, 0xbc, 0x9f, 0x4d, 0x7e, 0xf3, 0xf9, 0x1f, 0xf9, 0xdf, 0xef, 0x76, 0xb6, 0xfb, 0x3c,
  0xbd, 0xd7, 0xef, 0x5a, 0xf1, 0x7b, 0xaf, 0xfd, 0x8e, 0xe7, 0x7c, 0xf7, 0xf2, 0xbf, 0xdd, 0xdb, 0xeb, 0x6c, 0x77, 0xba,
  0xbf, 0x6d, 0xd7, 0xe7, 0x7e, 0xd6, 0xbb, 0x9f, 0xed, 0xdb, 0xac, 0x7e, 0x75, 0xfb, 0xa7, 0xf5, 0xdf, 0xeb, 0x7e, 0xa7,
  0xdb, 0xbe, 0xf9, 0x5d, 0x6f, 0x76, 0xf7, 0xcb, 0xb3, 0xfd, 0xcf, 0xee, 0x3e, 0xd7, 0x79, 0xbb, 0xf5, 0x5f, 0xcf, 0x7a,
  0xe7, 0xe3, 0xbf, 0xbc, 0xde, 0x2d, 0x5e, 0xf7, 0xfb, 0x9d, 0x79, 0xdf, 0xef, 0x6e, 0xb6, 0xfb, 0x3d, 0xfc, 0x97, 0xcf,
  0x5e, 0xf3, 0xf9, 0x2f, 0xfd, 0x9e, 0xef, 0x74, 0xf7, 0xf3, 0xbe, 0x9d, 0xdb, 0xef, 0x6a, 0xf5, 0x3a, 0xbf, 0x7d, 0xcf,
  0xe7, 0x7e, 0xd7, 0xfa, 0xbf, 0xcd, 0xdf, 0xaa, 0x7c, 0x75, 0xfb, 0xb7, 0xed, 0xd7, 0xeb, 0x7e, 0xe6, 0xbb, 0x9e, 0xfd,
  0x59, 0xed, 0x76, 0xf7, 0xdb, 0xab, 0xf5, 0xcf, 0xef, 0x3e, 0xb7, 0x59, 0xbf, 0xf1, 0xdd, 0x4f, 0x7a, 0xf7, 0xeb, 0xb7,
  0xbc, 0xdf, 0x6c, 0x3e, 0xd7, 0xfb, 0x9b, 0xf9, 0x5f, 0xef, 0x7e, 0xa6, 0xf3, 0x3d, 0xfd, 0xd6, 0xaf, 0x5e, 0xf3, 0xfb,
  0xad, 0x7d, 0x9e, 0xef, 0x6c, 0xf7, 0xf3, 0xbf, 0xdc, 0x9b, 0xcf, 0x6e, 0xf3, 0xb8, 0x3f, 0x7d, 0xdf, 0xe7, 0x76, 0xd7,
  0xfb, 0xbe, 0xad, 0xdf, 0xae, 0x7a, 0x75, 0x7b, 0xb7, 0xfd, 0xcf, 0xe3, 0x7e, 0xe7, 0xfa, 0xbe, 0xdd, 0x5d, 0xeb, 0x74,
  0x77, 0xdb, 0xbb, 0xed, 0xc7, 0xef, 0x3e, 0xf6, 0x39, 0x9f, 0xf5, 0xdb, 0xcd, 0x7a, 0xf7, 0xeb, 0xaf, 0xb4, 0xdf, 0x6d,
  0x7e, 0xb7, 0xdb, 0x9f, 0xf9, 0xdd, 0x6f, 0x7e, 0xb6, 0xeb, 0x35, 0xfd, 0xd7, 0xee, 0x1e, 0xd3, 0xfb, 0xab, 0xfd, 0x1e,
  0xef, 0x7c, 0xe7, 0xf3, 0xbf, 0xdd, 0xda, 0xaf, 0x4e, 0xf7, 0xba, 0xbd, 0x7d, 0xdf, 0xe7, 0x6e, 0xd7, 0xfb, 0xbf, 0xec,
  0x9f, 0x8e, 0x7e, 0x71, 0xf9, 0x37, 0xfd, 0xdf, 0xeb, 0x76, 0xe7, 0xfb, 0xbe, 0xbd, 0x5d, 0xef, 0x72, 0xf5, 0x5b, 0xbb,
  0xfd, 0xcf, 0xe7, 0x3e, 0xf7, 0x78, 0xbf, 0xd5, 0xdf, 0xcb, 0x78, 0x77, 0xeb, 0xbf, 0xac, 0xd7, 0x6d, 0x7e, 0xf6, 0xbb,
  0x9f, 0xf9, 0xdb, 0xed, 0x7e, 0xb6, 0xfb, 0x2d, 0xf5, 0xd7, 0xef, 0x5e, 0xb3, 0xdb, 0xaf, 0xf9, 0x9c, 0x6f, 0x7c, 0xf7,
  0xe3, 0xb7, 0xdd, 0xdb, 0xee, 0x2e, 0xd7, 0xba, 0xbb, 0x7d, 0x5f, 0xe7, 0x7e, 0xc7, 0xf3, 0xbf, 0xed, 0xde, 0xae, 0x5e,
  0x75, 0xfb, 0xb5, 0x7d, 0xdf, 0xeb, 0x6e, 0xe7, 0xfb, 0xbe, 0xfc, 0x1d, 0xcf, 0x76, 0xf3, 0xd9, 0x3b, 0xfd, 0xcf, 0xef,
  0x36, 0xf7, 0x79, 0xbe, 0xb5, 0xdf, 0xcf, 0x7a, 0xf5, 0x6b, 0xbf, 0xbc, 0xcf, 0x65, 0x7e, 0xf7, 0xfa, 0x9f, 0xd9, 0xdf,
  0xeb, 0x7c, 0x36, 0xfb, 0x3d, 0xed, 0xd7, 0xef, 0x5e, 0xf2, 0xbb, 0x8f, 0xfd, 0x9a, 0xed, 0x7c, 0xf7, 0xf3, 0xaf, 0xd5,
  0xdb, 0xef, 0x6e, 0xb7, 0x9a, 0xbf, 0x79, 0xdd, 0x67, 0x7e, 0xd7, 0xeb, 0xb7, 0xed, 0xdf, 0xae, 0x3e, 0x55, 0xfb, 0xb3,
  0xfd, 0x5f, 0xeb, 0x7e, 0xe7, 0xf3, 0xbe, 0xfd, 0x5c, 0xaf, 0x56, 0xf7, 0xdb, 0xb9, 0x7d, 0xcf, 0xef, 0x2e, 0xf7, 0x79,
  0xbf, 0xf4, 0x9f, 0xcf, 0x7a, 0xf3, 0xe9, 0x3f, 0xbc, 0xdf, 0x6d, 0x76, 0xf7, 0xfb, 0x9e, 0xb9, 0xdf, 0xef, 0x7a, 0xb4,
  0x7b, 0x3d, 0xfd, 0xc7, 0xe7, 0x5e, 0xf3, 0xfa, 0xaf, 0xdd, 0x9e, 0xeb, 0x7c, 0x77, 0xf3, 0xbf, 0xcd, 0xd3, 0xef, 0x6e,
  0xf6, 0xba, 0x9f, 0x7d, 0xdb, 0xe5, 0x7e, 0xd7, 0xfb, 0xaf, 0xe5, 0xdf, 0xae, 0x7e, 0x35, 0xdb, 0xb7, 0xf9, 0xdd, 0x6b,
  0x7e, 0xe7, 0xeb, 0xb6, 0xfd, 0x5d, 0xee, 0x36, 0xd7, 0xdb, 0xbb, 0xfd, 0x4f, 0xef, 0x3e, 0xe7, 0x71, 0xbf, 0xf5, 0xde,
  0x8f, 0x5a, 0xf7, 0xeb, 0xbd, 0x3c, 0xdf, 0x6d, 0x6e, 0xf7, 0xfb, 0x9f, 0xf8, 0x9f, 0xcf, 0x7e, 0xb2, 0xf9, 0x3d, 0xfd,
  0xd7, 0xef, 0x56, 0xf3, 0xfb, 0xae, 0xbd, 0x9e, 0xef, 0x78, 0xf5, 0x73, 0xbf, 0xdd, 0xcb, 0xe7, 0x6e, 0xf7, 0xba, 0xbf,
  0x5d, 0xdf, 0xe3, 0x7c, 0x57, 0xfb, 0xbf, 0xed, 0xd7, 0xae, 0x7e, 0x74, 0xbb, 0x97, 0xfd, 0xdb, 0xe9, 0x7e, 0xe7, 0xfb,
  0xae, 0xf5, 0x5d, 0xef, 0x76, 0xb7, 0xdb, 0xbb, 0xf9, 0xcd, 0x6f, 0x3e, 0xf7, 0x69, 0xb7, 0xf5, 0xdf, 0xce, 0x3a, 0xd7,
  0xeb, 0xbb, 0xbc, 0x5f, 0x6d, 0x7e, 0xe7, 0xf3, 0x9f, 0xf9, 0xde, 0xaf, 0x5e, 0xb6, 0xfb, 0x3d, 0x7d, 0xd7, 0xef, 0x4e,
  0xf3, 0xfb, 0xaf, 0xfc, 0x9e, 0xcf, 0x7c, 0xf3, 0xf1, 0x3f, 0xdd, 0xdb, 0xef, 0x66, 0xf7, 0xba, 0xbe, 0x3d, 0xdf, 0xe7,
  0x7a, 0xd5, 0x7b, 0xbf, 0xed, 0xcf, 0xa6, 0x7e, 0x75, 0xfa, 0xb7, 0xdd, 0xdf, 0xeb, 0x7c, 0x67, 0xfb, 0xbe, 0xed, 0x55,
  0xef, 0x76, 0xf6, 0x9b, 0x9b, 0xfd, 0xcb, 0xed, 0x3e, 0xf7, 0x79, 0xaf, 0xf5, 0xdf, 0xcf, 0x7a, 0xb7, 0xcb, 0xbf, 0xb8,
  0xdd, 0x6d, 0x7e, 0xf7, 0xeb, 0x97, 0xf9, 0xdf, 0xee, 0x3e, 0x96, 0xfb, 0x39, 0xfd, 0x57, 0xef, 0x5e, 0xe3, 0xf3, 0xaf,
  0xfd, 0x9e, 0xaf, 0x5c, 0xf7, 0xf3, 0xbd, 0x5d, 0xdb, 0xef, 0x6e, 0xf7, 0xba, 0xbf, 0x7c, 0x9f, 0xc7, 0x7e, 0xd3, 0xf9,
  0x3f, 0xed, 0xdf, 0xae, 0x76, 0x75, 0xfb, 0xb6, 0xbd, 0xdf, 0xeb, 0x7a, 0xe5, 0x7b, 0xbe, 0xfd, 0x4d, 0xe7, 0x76, 0xf7,
  0xda, 0xbb, 0xdd, 0xcf, 0xeb, 0x3c, 0x77, 0x79, 0xbf, 0xe5, 0xd7, 0xcf, 0x7a, 0xf6, 0xab, 0x9f, 0xbc, 0xdb, 0x6d, 0x7e,
  0xf7, 0xfb, 0x8f, 0xf1, 0xdf, 0xef, 0x7e, 0xb6, 0xdb, 0x3d, 0xf9, 0xd5, 0x6f, 0x5e, 0xf3, 0xeb, 0xa7, 0xfd, 0x9e, 0xee,
  0x3c, 0xd7, 0xf3, 0xbb, 0xdd, 0x5b, 0xef, 0x6e, 0xe7, 0xb2, 0xbf, 0x7d, 0xde, 0xa7, 0x5e, 0xd7, 0xfb, 0xbd, 0x6d, 0xdf,
  0xae, 0x6e, 0x75, 0xfb, 0xb7, 0xfc, 0x9f, 0xcb, 0x7e, 0xe3, 0xf9, 0x3e, 0xfd, 0x5d, 0xef, 0x76, 0xf7, 0xdb, 0xba, 0xbd,
  0xcf, 0xef, 0x3a, 0xf5, 0x79, 0xbf, 0xf5, 0xcf, 0xc7, 0x7a, 0xf7, 0xea, 0xbf, 0x9c, 0xdf, 0x69, 0x7c, 0x77, 0xfb, 0x9f,
  0xe9, 0xd7, 0xef, 0x7e, 0xb6, 0xbb, 0x1d, 0xfd, 0xd3, 0xed, 0x5e, 0xf3, 0xfb, 0xaf, 0xf5, 0x9e, 0xef, 0x7c, 0xb7, 0xd3,
  0xbf, 0xd9, 0xd9, 0x6f, 0x6e, 0xf7, 0xaa, 0xb7, 0x7d, 0xdf, 0xe6, 0x3e, 0xd7, 0xfb, 0xbb, 0xed, 0x5f, 0xae, 0x7e, 0x65,
  0xf3, 0xb7, 0xfd, 0xde, 0xab, 0x5e, 0xe7, 0xfb, 0xbc, 0x7d, 0x5d, 0xef, 0x66, 0xf7, 0xdb, 0xbb, 0xfc, 0x8f, 0xcf, 0x3e,
  0xf3, 0x79, 0x3f, 0xf5, 0xdf, 0xcf, 0x72, 0xf7, 0xeb, 0xbe, 0xbc, 0xdf, 0x6d, 0x7a, 0xf5, 0x7b, 0x9f, 0xf9, 0xcf, 0xe7,
  0x7e, 0xb6, 0xfa, 0x3d, 0xdd, 0xd7, 0xeb, 0x5c, 0x73, 0xfb, 0xaf, 0xed, 0x96, 0xef, 0x7c, 0xf6, 0xb3, 0x9f, 0xdd, 0xdb,
  0xed, 0x6e, 0xf7, 0xba, 0xaf, 0x75, 0xdf, 0xe7, 0x7e, 0x97, 0xdb, 0xbf, 0xe9, 0xdd, 0x2e, 0x7e, 0x75, 0xeb, 0xb7, 0xfd,
  0xdf, 0xea, 0x3e, 0xc7, 0xfb, 0xba, 0xfd, 0x5d, 0xef, 0x76, 0xe7, 0xd3, 0xbb, 0xfd, 0xce, 0xaf, 0x1e, 0xf7, 0x79, 0xbd,
  0x75, 0xdf, 0xcf, 0x6a, 0xf7, 0xeb, 0xbf, 0xbc, 0x9f, 0x4d, 0x7e, 0xf3, 0xf9, 0x1f, 0xf9, 0xdf, 0xef, 0x76, 0xb6, 0xfb,
  0x3c, 0xbd, 0xd7, 0xef, 0x5a, 0xf1, 0x7b, 0xaf, 0xfd, 0x8e, 0xe7, 0x7c, 0xf7, 0xf2, 0xbf, 0xdd, 0xdb, 0xeb, 0x6c, 0x77,
  0xba, 0xbf, 0x6d, 0xd7, 0xe7, 0x7e, 0xd6, 0xbb, 0x9f, 0xed, 0xdb, 0xac, 0x7e, 0x75, 0xfb, 0xa7, 0xf5, 0xdf, 0xeb, 0x7e,
  0xa7, 0xdb, 0xbe, 0xf9, 0x5d, 0x6f, 0x76, 0xf7, 0xcb, 0xb3, 0xfd, 0xcf, 0xee, 0x3e, 0xd7, 0x79, 0xbb, 0xf5, 0x5f, 0xcf,
  0x7a, 0xe7, 0xe3, 0xbf, 0xbc, 0xde, 0x2d, 0x5e, 0xf7, 0xfb, 0x9d, 0x79, 0xdf, 0xef, 0x6e, 0xb6, 0xfb, 0x3d, 0xfc, 0x97,
  0xcf, 0x5e, 0xf3, 0xf9, 0x2f, 0xfd, 0x9e, 0xef, 0x74, 0xf7, 0xf3, 0xbe, 0x9d, 0xdb, 0xef, 0x6a, 0xf5, 0x3a, 0xbf, 0x7d,
  0xcf, 0xe7, 0x7e, 0xd7, 0xfa, 0xbf, 0xcd, 0xdf, 0xaa, 0x7c, 0x75, 0xfb, 0xb7, 0xed, 0xd7, 0xeb, 0x7e, 0xe6, 0xbb, 0x9e,
  0xfd, 0x59, 0xed, 0x76, 0xf7, 0xdb, 0xab, 0xf5, 0xcf, 0xef, 0x3e, 0xb7, 0x59, 0xbf, 0xf1, 0xdd, 0x4f, 0x7a, 0xf7, 0xeb,
  0xb7, 0xbc, 0xdf, 0x6c, 0x3e, 0xd7, 0xfb, 0x9b, 0xf9, 0x5f, 0xef, 0x7e, 0xa6, 0xf3, 0x3d, 0xfd, 0xd6, 0xaf, 0x5e, 0xf3,
  0xfb, 0xad, 0x7d, 0x9e, 0xef, 0x6c, 0xf7, 0xf3, 0xbf, 0xdc, 0x9b, 0xcf, 0x6e, 0xf3, 0xb8, 0x3f, 0x7d, 0xdf, 0xe7, 0x76,
  0xd7, 0xfb, 0xbe, 0xad, 0xdf, 0xae, 0x7a, 0x75, 0x7b, 0xb7, 0xfd, 0xcf, 0xe3, 0x7e, 0xe7, 0xfa, 0xbe, 0xdd, 0x5d, 0xeb,
  0x74, 0x77, 0xdb, 0xbb, 0xed, 0xc7, 0xef, 0x3e, 0xf6, 0x39, 0x9f, 0xf5, 0xdb, 0xcd, 0x7a, 0xf7, 0xeb, 0xaf, 0xb4, 0xdf,
  0x6d, 0x7e, 0xb7, 0xdb, 0x9f, 0xf9, 0xdd, 0x6f, 0x7e, 0xb6, 0xeb, 0x35, 0xfd, 0xd7, 0xee, 0x1e, 0xd3, 0xfb, 0xab, 0xfd,
  0x1e, 0xef, 0x7c, 0xe7, 0xf3, 0xbf, 0xdd, 0xda, 0xaf, 0x4e, 0xf7, 0xba, 0xbd, 0x7d, 0xdf, 0xe7, 0x6e, 0xd7, 0xfb, 0xbf,
  0xec, 0x9f, 0x8e, 0x7e, 0x71, 0xf9, 0x37, 0xfd, 0xdf, 0xeb, 0x76, 0xe7, 0xfb, 0xbe, 0xbd, 0x5d, 0xef, 0x72, 0xf5, 0x5b,
  0xbb, 0xfd, 0xcf, 0xe7, 0x3e, 0xf7, 0x78, 0xbf, 0xd5, 0xdf, 0xcb, 0x78, 0x77, 0xeb, 0xbf, 0xac, 0xd7, 0x6d, 0x7e, 0xf6,
  0xbb, 0x9f, 0xf9, 0xdb, 0xed, 0x7e, 0xb6, 0xfb, 0x2d, 0xf5, 0xd7, 0xef, 0x5e, 0xb3, 0xdb, 0xaf, 0xf9, 0x9c, 0x6f, 0x7c,
  0xf7, 0xe3, 0xb7, 0xdd, 0xdb, 0xee, 0x2e, 0xd7, 0xba, 0xbb, 0x7d, 0x5f, 0xe7, 0x7e, 0xc7, 0xf3, 0xbf, 0xed, 0xde, 0xae,
  0x5e, 0x75, 0xfb, 0xb5, 0x7d, 0xdf, 0xeb, 0x6e, 0xe7, 0xfb, 0xbe, 0xfc, 0x1d, 0xcf, 0x76, 0xf3, 0xd9, 0x3b, 0xfd, 0xcf,
  0xef, 0x36, 0xf7, 0x79, 0xbe, 0xb5, 0xdf, 0xcf, 0x7a, 0xf5, 0x6b, 0xbf, 0xbc, 0xcf, 0x65, 0x7e, 0xf7, 0xfa, 0x9f, 0xd9,
  0xdf, 0xeb, 0x7c, 0x36, 0xfb, 0x3d, 0xed, 0xd7, 0xef, 0x5e, 0xf2, 0xbb, 0x8f, 0xfd, 0x9a, 0xed, 0x7c, 0xf7, 0xf3, 0xaf,
  0xd5, 0xdb, 0xef, 0x6e, 0xb7, 0x9a, 0xbf, 0x79, 0xdd, 0x67, 0x7e, 0xd7, 0xeb, 0xb7, 0xed, 0xdf, 0xae, 0x3e, 0x55, 0xfb,
  0xb3, 0xfd, 0x5f, 0xeb, 0x7e, 0xe7, 0xf3, 0xbe, 0xfd, 0x5c, 0xaf, 0x56, 0xf7, 0xdb, 0xb9, 0x7d, 0xcf, 0xef, 0x2e, 0xf7,
  0x79, 0xbf, 0xf4, 0x9f, 0xcf, 0x7a, 0xf3, 0xe9, 0x3f, 0xbc, 0xdf, 0x6d, 0x76, 0xf7, 0xfb, 0x9e, 0xb9, 0xdf, 0xef, 0x7a,
  0xb4, 0x7b, 0x3d, 0xfd, 0xc7, 0xe7, 0x5e, 0xf3, 0xfa, 0xaf, 0xdd, 0x9e, 0xeb, 0x7c, 0x77, 0xf3, 0xbf, 0xcd, 0xd3, 0xef,
  0x6e, 0xf6, 0xba, 0x9f, 0x7d, 0xdb, 0xe5, 0x7e, 0xd7, 0xfb, 0xaf, 0xe5, 0xdf, 0xae, 0x7e, 0x35, 0xdb, 0xb7, 0xf9, 0xdd,
  0x6b, 0x7e, 0xe7, 0xeb, 0xb6, 0xfd, 0x5d, 0xee, 0x36, 0xd7, 0xdb, 0xbb, 0xfd, 0x4f, 0xef, 0x3e, 0xe7, 0x71, 0xbf, 0xf5,
  0xde, 0x8f, 0x5a, 0xf7, 0xeb, 0xbd, 0x3c, 0xdf, 0x6d, 0x6e, 0xf7, 0xfb, 0x9f, 0xf8, 0x9f, 0xcf, 0x7e, 0xb2, 0xf9, 0x3d,
  0xfd, 0xd7, 0xef, 0x56, 0xf3, 0xfb, 0xae, 0xbd, 0x9e, 0xef, 0x78, 0xf5, 0x73, 0xbf, 0xdd, 0xcb, 0xe7, 0x6e, 0xf7, 0xba,
  0xbf, 0x5d, 0xdf, 0xe3, 0x7c, 0x57, 0xfb, 0xbf, 0xed, 0xd7, 0xae, 0x7e, 0x74, 0xbb, 0x97, 0xfd, 0xdb, 0xe9, 0x7e, 0xe7,
  0xfb, 0xae, 0xf5, 0x5d, 0xef, 0x76, 0xb7, 0xdb, 0xbb, 0xf9, 0xcd, 0x6f, 0x3e, 0xf7, 0x69, 0xb7, 0xf5, 0xdf, 0xce, 0x3a,
  0xd7, 0xeb, 0xbb, 0xbc, 0x5f, 0x6d, 0x7e, 0xe7, 0xf3, 0x9f, 0xf9, 0xde, 0xaf, 0x5e, 0xb6, 0xfb, 0x3d, 0x7d, 0xd7, 0xef,
  0x4e, 0xf3, 0xfb, 0xaf, 0xfc, 0x9e, 0xcf, 0x7c, 0xf3, 0xf1, 0x3f, 0xdd, 0xdb, 0xef, 0x66, 0xf7, 0xba, 0xbe, 0x3d, 0xdf,
  0xe7, 0x7a, 0xd5, 0x7b, 0xbf, 0xed, 0xcf, 0xa6, 0x7e, 0x75, 0xfa, 0xb7, 0xdd, 0xdf, 0xeb, 0x7c, 0x67, 0xfb, 0xbe, 0xed,
  0x55, 0xef, 0x76, 0xf6, 0x9b, 0x9b, 0xfd, 0xcb, 0xed, 0x3e, 0xf7, 0x79, 0xaf, 0xf5, 0xdf, 0xcf, 0x7a, 0xb7, 0xcb, 0xbf,
  0xb8, 0xdd, 0x6d, 0x7e, 0xf7, 0xeb, 0x97, 0xf9, 0xdf, 0xee, 0x3e, 0x96, 0xfb, 0x39, 0xfd, 0x57, 0xef, 0x5e, 0xe3, 0xf3,
  0xaf, 0xfd, 0x9e, 0xaf, 0x5c, 0xf7, 0xf3, 0xbd, 0x5d, 0xdb, 0xef, 0x6e, 0xf7, 0xba, 0xbf, 0x7c, 0x9f, 0xc7, 0x7e, 0xd3,
  0xf9, 0x3f, 0xed, 0xdf, 0xae, 0x76, 0x75, 0xfb, 0xb6, 0xbd, 0xdf, 0xeb, 0x7a, 0xe5, 0x7b, 0xbe, 0xfd, 0x4d, 0xe7, 0x76,
  0xf7, 0xda, 0xbb, 0xdd, 0xcf, 0xeb, 0x3c, 0x77, 0x79, 0xbf, 0xe5, 0xd7, 0xcf, 0x7a, 0xf6, 0xab, 0x9f, 0xbc, 0xdb, 0x6d,
  0x7e, 0xf7, 0xfb, 0x8f
};

#if 0

/// C++ program that generates the pre_sieved arrays
/// used in pre_sieve.cpp.
///

#include <sieve/Sieve.hpp>
#include <generate_primes.hpp>

#include <iostream>
#include <iomanip>
#include <vector>

int main()
{
  const std::vector<std::vector<long>> vect =
  {{
    { 17, 19 },
    { 23, 29 },
    { 31, 37 },
    { 41, 43 },
    { 47, 53 },
    { 59, 61 },
    { 67, 71 }
  }};

  std::cout << "const primecount::Array<std::initializer_list<uint8_t>, "
            << vect.size() << "> pre_sieved_arrays =" << std::endl;
  std::cout << "{{" << std::endl;

  for (const auto& v : vect)
  {
    long min_size = 3000; // bytes
    long prime_product = 1;
    for (long prime : v) prime_product *= prime;
    long factor = 2;
    while (prime_product * factor < min_size) factor++;
    long bytes = prime_product * factor;

    using namespace primecount;
    auto primes = generate_primes<int>(vect.back().back());
    Sieve sieve(prime_product * 30, prime_product * 30 * factor, primes.size());
    std::fill(sieve.sieve_.begin(), sieve.sieve_.end(), ~0ull);
    uint8_t* sieve_array = (uint8_t*) sieve.sieve_.data();

    for (unsigned i = 0; i < v.size(); i++)
      sieve.cross_off(v[i], i + 4);

    std::cout << "  { ";

    for (long j = 0; j < bytes; j++)
    {
      if (j != 0 && j % 20 == 0)
        std::cout << std::endl << "    ";
      std::cout << "0x" << std::hex << std::setw(2) << std::setfill('0') << (int) sieve_array[j];
      if (j + 1 < bytes)
        std::cout << ((j+1) % 20 == 0 ? "," : ", ");
      else
        std::cout << (v.back() < vect.back().back() ? " }," : " }") << std::endl;
    }
  }

  std::cout << "}};" << std::endl;

  return 0;
}

#endif

/// Static arrays from which the primes and multiples of primes have
/// been removed. Our Sieve::pre_sieve() method requires that each
/// pre_sieved lookup table corresponds to exactly 2 sieving primes.
///
/// pre_sieved_arrays[0] = { 17, 19 }
/// pre_sieved_arrays[1] = { 23, 29 }
/// pre_sieved_arrays[2] = { 31, 37 }
/// pre_sieved_arrays[3] = { 41, 43 }
/// pre_sieved_arrays[4] = { 47, 53 }
/// pre_sieved_arrays[5] = { 59, 61 }
/// pre_sieved_arrays[6] = { 67, 71 }
///
const primecount::Array<std::initializer_list<uint8_t>, 7> pre_sieved_arrays =
{{
  { 0xcf, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0x7d, 0xfb, 0xfd, 0xdf, 0xbf, 0xff, 0xfe, 0xfe, 0xef, 0xff, 0xf7, 0xef, 0xfb, 0xdf,
    0x7f, 0xff, 0xff, 0xf5, 0xfb, 0x7f, 0xdf, 0xbd, 0xff, 0xbf, 0xfe, 0xfe, 0xff, 0xe7, 0xef, 0xff, 0xff, 0x7b, 0xdf, 0xff,
    0xfd, 0xfb, 0xf7, 0xdf, 0x3f, 0xff, 0xfd, 0xfe, 0xbf, 0xff, 0xf6, 0xef, 0xef, 0xff, 0x7f, 0xff, 0xfb, 0xdd, 0xfb, 0xff,
    0xdf, 0xb7, 0xff, 0x7f, 0xfe, 0xfd, 0xff, 0xb7, 0xef, 0xfe, 0xff, 0x6f, 0xff, 0xff, 0xfd, 0xfb, 0xdf, 0xdf, 0xbf, 0xff,
    0xf7, 0xfe, 0x7f, 0xff, 0xf5, 0xef, 0xbf, 0xff, 0x7e, 0xff, 0xef, 0xfd, 0xfb, 0xff, 0xdb, 0x9f, 0xff, 0xff, 0xfe, 0xf7,
    0xff, 0x77, 0xef, 0xfd, 0xff, 0x3f, 0xff, 0xfe, 0xfd, 0xeb, 0xff, 0xdf, 0xbf, 0xfb, 0xdf, 0xfe, 0xff, 0xff, 0xf7, 0xef,
    0x7f, 0xff, 0x7d, 0xff, 0xbf, 0xfd, 0xfa, 0xff, 0xcf, 0xbf, 0xff, 0xff, 0xfa, 0xdf, 0xff, 0xf7, 0xef, 0xf7, 0xff, 0x7f,
    0xff, 0xfd, 0xfd, 0xbb, 0xff, 0xde, 0xbf, 0xef, 0xff, 0xfe, 0xff, 0xfb, 0xd7, 0xef, 0xff, 0xff, 0x77, 0xff, 0x7f, 0xfd,
    0xf9, 0xff, 0x9f, 0xbf, 0xfe, 0xff, 0xee, 0xff, 0xff, 0xf7, 0xeb, 0xdf, 0xff, 0x7f, 0xff, 0xf7, 0xfd, 0x7b, 0xff, 0xdd,
    0xbf, 0xbf, 0xff, 0xfe, 0xff, 0xef, 0xf7, 0xef, 0xff, 0xfb, 0x5f, 0xff, 0xff, 0xfd, 0xf3, 0xff, 0x5f, 0xbf, 0xfd, 0xff,
    0xbe, 0xff, 0xfe, 0xf7, 0xef, 0xff, 0xff, 0x7f, 0xfb, 0xdf, 0xfd, 0xfb, 0xff, 0xd7, 0xbf, 0x7f, 0xff, 0xfc, 0xff, 0xbf,
    0xf7, 0xee, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xf9, 0xdb, 0xff, 0xdf, 0xbf, 0xf7, 0xff, 0x7e, 0xff, 0xfd, 0xf7, 0xaf, 0xff,
    0xfe, 0x7f, 0xef, 0xff, 0xfd, 0xfb, 0xfb, 0xdf, 0xbf, 0xff, 0xff, 0xf6, 0xff, 0x7f, 0xf7, 0xed, 0xff, 0xbf, 0x7f, 0xfe,
    0xff, 0xed, 0xfb, 0xff, 0xdf, 0xbb, 0xdf, 0xff, 0xfe, 0xff, 0xf7, 0xf7, 0x6f, 0xff, 0xfd, 0x7f, 0xbf, 0xff, 0xfc, 0xfb,
    0xef, 0xdf, 0xbf, 0xff, 0xfb, 0xde, 0xff, 0xff, 0xf7, 0xe7, 0xff, 0x7f, 0x7f, 0xfd, 0xff, 0xbd, 0xfb, 0xfe, 0xdf, 0xaf,
    0xff, 0xff, 0xfe, 0xfb, 0xdf, 0xf7, 0xef, 0xff, 0xf7, 0x7f, 0x7f, 0xff, 0xfd, 0xfb, 0xbf, 0xdf, 0xbe, 0xff, 0xef, 0xfe,
    0xff, 0xff, 0xf3, 0xcf, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0x7d, 0xfb, 0xfd, 0xdf, 0xbf, 0xff, 0xfe, 0xfe, 0xef, 0xff, 0xf7,
    0xef, 0xfb, 0xdf, 0x7f, 0xff, 0xff, 0xf5, 0xfb, 0x7f, 0xdf, 0xbd, 0xff, 0xbf, 0xfe, 0xfe, 0xff, 0xe7, 0xef, 0xff, 0xff,
    0x7b, 0xdf, 0xff, 0xfd, 0xfb, 0xf7, 0xdf, 0x3f, 0xff, 0xfd, 0xfe, 0xbf, 0xff, 0xf6, 0xef, 0xef, 0xff, 0x7f, 0xff, 0xfb,
    0xdd, 0xfb, 0xff, 0xdf, 0xb7, 0xff, 0x7f, 0xfe, 0xfd, 0xff, 0xb7, 0xef, 0xfe, 0xff, 0x6f, 0xff, 0xff, 0xfd, 0xfb, 0xdf,
    0xdf, 0xbf, 0xff, 0xf7, 0xfe, 0x7f, 0xff, 0xf5, 0xef, 0xbf, 0xff, 0x7e, 0xff, 0xef, 0xfd, 0xfb, 0xff, 0xdb, 0x9f, 0xff,
    0xff, 0xfe, 0xf7, 0xff, 0x77, 0xef, 0xfd, 0xff, 0x3f, 0xff, 0xfe, 0xfd, 0xeb, 0xff, 0xdf, 0xbf, 0xfb, 0xdf, 0xfe, 0xff,
    0xff, 0xf7, 0xef, 0x7f, 0xff, 0x7d, 0xff, 0xbf, 0xfd, 0xfa, 0xff, 0xcf, 0xbf, 0xff, 0xff, 0xfa, 0xdf, 0xff, 0xf7, 0xef,
    0xf7, 0xff, 0x7f, 0xff, 0xfd, 0xfd, 0xbb, 0xff, 0xde, 0xbf, 0xef, 0xff, 0xfe, 0xff, 0xfb, 0xd7, 0xef, 0xff, 0xff, 0x77,
    0xff, 0x7f, 0xfd, 0xf9, 0xff, 0x9f, 0xbf, 0xfe, 0xff, 0xee, 0xff, 0xff, 0xf7, 0xeb, 0xdf, 0xff, 0x7f, 0xff, 0xf7, 0xfd,
    0x7b, 0xff, 0xdd, 0xbf, 0xbf, 0xff, 0xfe, 0xff, 0xef, 0xf7, 0xef, 0xff, 0xfb, 0x5f, 0xff, 0xff, 0xfd, 0xf3, 0xff, 0x5f,
    0xbf, 0xfd, 0xff, 0xbe, 0xff, 0xfe, 0xf7, 0xef, 0xff, 0xff, 0x7f, 0xfb, 0xdf, 0xfd, 0xfb, 0xff, 0xd7, 0xbf, 0x7f, 0xff,
    0xfc, 0xff, 0xbf, 0xf7, 0xee, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xf9, 0xdb, 0xff, 0xdf, 0xbf, 0xf7, 0xff, 0x7e, 0xff, 0xfd,
    0xf7, 0xaf, 0xff, 0xfe, 0x7f, 0xef, 0xff, 0xfd, 0xfb, 0xfb, 0xdf, 0xbf, 0xff, 0xff, 0xf6, 0xff, 0x7f, 0xf7, 0xed, 0xff,
    0xbf, 0x7f, 0xfe, 0xff, 0xed, 0xfb, 0xff, 0xdf, 0xbb, 0xdf, 0xff, 0xfe, 0xff, 0xf7, 0xf7, 0x6f, 0xff, 0xfd, 0x7f, 0xbf,
    0xff, 0xfc, 0xfb, 0xef, 0xdf, 0xbf, 0xff, 0xfb, 0xde, 0xff, 0xff, 0xf7, 0xe7, 0xff, 0x7f, 0x7f, 0xfd, 0xff, 0xbd, 0xfb,
    0xfe, 0xdf, 0xaf, 0xff, 0xff, 0xfe, 0xfb, 0xdf, 0xf7, 0xef, 0xff, 0xf7, 0x7f, 0x7f, 0xff, 0xfd, 0xfb, 0xbf, 0xdf, 0xbe,
    0xff, 0xef, 0xfe, 0xff, 0xff, 0xf3, 0xcf, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0x7d, 0xfb, 0xfd, 0xdf, 0xbf, 0xff, 0xfe, 0xfe,
    0xef, 0xff, 0xf7, 0xef, 0xfb, 0xdf, 0x7f, 0xff, 0xff, 0xf5, 0xfb, 0x7f, 0xdf, 0xbd, 0xff, 0xbf, 0xfe, 0xfe, 0xff, 0xe7,
    0xef, 0xff, 0xff, 0x7b, 0xdf, 0xff, 0xfd, 0xfb, 0xf7, 0xdf, 0x3f, 0xff, 0xfd, 0xfe, 0xbf, 0xff, 0xf6, 0xef, 0xef, 0xff,
    0x7f, 0xff, 0xfb, 0xdd, 0xfb, 0xff, 0xdf, 0xb7, 0xff, 0x7f, 0xfe, 0xfd, 0xff, 0xb7, 0xef, 0xfe, 0xff, 0x6f, 0xff, 0xff,
    0xfd, 0xfb, 0xdf, 0xdf, 0xbf, 0xff, 0xf7, 0xfe, 0x7f, 0xff, 0xf5, 0xef, 0xbf, 0xff, 0x7e, 0xff, 0xef, 0xfd, 0xfb, 0xff,
    0xdb, 0x9f, 0xff, 0xff, 0xfe, 0xf7, 0xff, 0x77, 0xef, 0xfd, 0xff, 0x3f, 0xff, 0xfe, 0xfd, 0xeb, 0xff, 0xdf, 0xbf, 0xfb,
    0xdf, 0xfe, 0xff, 0xff, 0xf7, 0xef, 0x7f, 0xff, 0x7d, 0xff, 0xbf, 0xfd, 0xfa, 0xff, 0xcf, 0xbf, 0xff, 0xff, 0xfa, 0xdf,
    0xff, 0xf7, 0xef, 0xf7, 0xff, 0x7f, 0xff, 0xfd, 0xfd, 0xbb, 0xff, 0xde, 0xbf, 0xef, 0xff, 0xfe, 0xff, 0xfb, 0xd7, 0xef,
    0xff, 0xff, 0x77, 0xff, 0x7f, 0xfd, 0xf9, 0xff, 0x9f, 0xbf, 0xfe, 0xff, 0xee, 0xff, 0xff, 0xf7, 0xeb, 0xdf, 0xff, 0x7f,
    0xff, 0xf7, 0xfd, 0x7b, 0xff, 0xdd, 0xbf, 0xbf, 0xff, 0xfe, 0xff, 0xef, 0xf7, 0xef, 0xff, 0xfb, 0x5f, 0xff, 0xff, 0xfd,
    0xf3, 0xff, 0x5f, 0xbf, 0xfd, 0xff, 0xbe, 0xff, 0xfe, 0xf7, 0xef, 0xff, 0xff, 0x7f, 0xfb, 0xdf, 0xfd, 0xfb, 0xff, 0xd7,
    0xbf, 0x7f, 0xff, 0xfc, 0xff, 0xbf, 0xf7, 0xee, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xf9, 0xdb, 0xff, 0xdf, 0xbf, 0xf7, 0xff,
    0x7e, 0xff, 0xfd, 0xf7, 0xaf, 0xff, 0xfe, 0x7f, 0xef, 0xff, 0xfd, 0xfb, 0xfb, 0xdf, 0xbf, 0xff, 0xff, 0xf6, 0xff, 0x7f,
    0xf7, 0xed, 0xff, 0xbf, 0x7f, 0xfe, 0xff, 0xed, 0xfb, 0xff, 0xdf, 0xbb, 0xdf, 0xff, 0xfe, 0xff, 0xf7, 0xf7, 0x6f, 0xff,
    0xfd, 0x7f, 0xbf, 0xff, 0xfc, 0xfb, 0xef, 0xdf, 0xbf, 0xff, 0xfb, 0xde, 0xff, 0xff, 0xf7, 0xe7, 0xff, 0x7f, 0x7f, 0xfd,
    0xff, 0xbd, 0xfb, 0xfe, 0xdf, 0xaf, 0xff, 0xff, 0xfe, 0xfb, 0xdf, 0xf7, 0xef, 0xff, 0xf7, 0x7f, 0x7f, 0xff, 0xfd, 0xfb,
    0xbf, 0xdf, 0xbe, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xf3, 0xcf, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0x7d, 0xfb, 0xfd, 0xdf, 0xbf,
    0xff, 0xfe, 0xfe, 0xef, 0xff, 0xf7, 0xef, 0xfb, 0xdf, 0x7f, 0xff, 0xff, 0xf5, 0xfb, 0x7f, 0xdf, 0xbd, 0xff, 0xbf, 0xfe,
    0xfe, 0xff, 0xe7, 0xef, 0xff, 0xff, 0x7b, 0xdf, 0xff, 0xfd, 0xfb, 0xf7, 0xdf, 0x3f, 0xff, 0xfd, 0xfe, 0xbf, 0xff, 0xf6,
    0xef, 0xef, 0xff, 0x7f, 0xff, 0xfb, 0xdd, 0xfb, 0xff, 0xdf, 0xb7, 0xff, 0x7f, 0xfe, 0xfd, 0xff, 0xb7, 0xef, 0xfe, 0xff,
    0x6f, 0xff, 0xff, 0xfd, 0xfb, 0xdf, 0xdf, 0xbf, 0xff, 0xf7, 0xfe, 0x7f, 0xff, 0xf5, 0xef, 0xbf, 0xff, 0x7e, 0xff, 0xef,
    0xfd, 0xfb, 0xff, 0xdb, 0x9f, 0xff, 0xff, 0xfe, 0xf7, 0xff, 0x77, 0xef, 0xfd, 0xff, 0x3f, 0xff, 0xfe, 0xfd, 0xeb, 0xff,
    0xdf, 0xbf, 0xfb, 0xdf, 0xfe, 0xff, 0xff, 0xf7, 0xef, 0x7f, 0xff, 0x7d, 0xff, 0xbf, 0xfd, 0xfa, 0xff, 0xcf, 0xbf, 0xff,
    0xff, 0xfa, 0xdf, 0xff, 0xf7, 0xef, 0xf7, 0xff, 0x7f, 0xff, 0xfd, 0xfd, 0xbb, 0xff, 0xde, 0xbf, 0xef, 0xff, 0xfe, 0xff,
    0xfb, 0xd7, 0xef, 0xff, 0xff, 0x77, 0xff, 0x7f, 0xfd, 0xf9, 0xff, 0x9f, 0xbf, 0xfe, 0xff, 0xee, 0xff, 0xff, 0xf7, 0xeb,
    0xdf, 0xff, 0x7f, 0xff, 0xf7, 0xfd, 0x7b, 0xff, 0xdd, 0xbf, 0xbf, 0xff, 0xfe, 0xff, 0xef, 0xf7, 0xef, 0xff, 0xfb, 0x5f,
    0xff, 0xff, 0xfd, 0xf3, 0xff, 0x5f, 0xbf, 0xfd, 0xff, 0xbe, 0xff, 0xfe, 0xf7, 0xef, 0xff, 0xff, 0x7f, 0xfb, 0xdf, 0xfd,
    0xfb, 0xff, 0xd7, 0xbf, 0x7f, 0xff, 0xfc, 0xff, 0xbf, 0xf7, 0xee, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xf9, 0xdb, 0xff, 0xdf,
    0xbf, 0xf7, 0xff, 0x7e, 0xff, 0xfd, 0xf7, 0xaf, 0xff, 0xfe, 0x7f, 0xef, 0xff, 0xfd, 0xfb, 0xfb, 0xdf, 0xbf, 0xff, 0xff,
    0xf6, 0xff, 0x7f, 0xf7, 0xed, 0xff, 0xbf, 0x7f, 0xfe, 0xff, 0xed, 0xfb, 0xff, 0xdf, 0xbb, 0xdf, 0xff, 0xfe, 0xff, 0xf7,
    0xf7, 0x6f, 0xff, 0xfd, 0x7f, 0xbf, 0xff, 0xfc, 0xfb, 0xef, 0xdf, 0xbf, 0xff, 0xfb, 0xde, 0xff, 0xff, 0xf7, 0xe7, 0xff,
    0x7f, 0x7f, 0xfd, 0xff, 0xbd, 0xfb, 0xfe, 0xdf, 0xaf, 0xff, 0xff, 0xfe, 0xfb, 0xdf, 0xf7, 0xef, 0xff, 0xf7, 0x7f, 0x7f,
    0xff, 0xfd, 0xfb, 0xbf, 0xdf, 0xbe, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xf3, 0xcf, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0x7d, 0xfb,
    0xfd, 0xdf, 0xbf, 0xff, 0xfe, 0xfe, 0xef, 0xff, 0xf7, 0xef, 0xfb, 0xdf, 0x7f, 0xff, 0xff, 0xf5, 0xfb, 0x7f, 0xdf, 0xbd,
    0xff, 0xbf, 0xfe, 0xfe, 0xff, 0xe7, 0xef, 0xff, 0xff, 0x7b, 0xdf, 0xff, 0xfd, 0xfb, 0xf7, 0xdf, 0x3f, 0xff, 0xfd, 0xfe,
    0xbf, 0xff, 0xf6, 0xef, 0xef, 0xff, 0x7f, 0xff, 0xfb, 0xdd, 0xfb, 0xff, 0xdf, 0xb7, 0xff, 0x7f, 0xfe, 0xfd, 0xff, 0xb7,
    0xef, 0xfe, 0xff, 0x6f, 0xff, 0xff, 0xfd, 0xfb, 0xdf, 0xdf, 0xbf, 0xff, 0xf7, 0xfe, 0x7f, 0xff, 0xf5, 0xef, 0xbf, 0xff,
    0x7e, 0xff, 0xef, 0xfd, 0xfb, 0xff, 0xdb, 0x9f, 0xff, 0xff, 0xfe, 0xf7, 0xff, 0x77, 0xef, 0xfd, 0xff, 0x3f, 0xff, 0xfe,
    0xfd, 0xeb, 0xff, 0xdf, 0xbf, 0xfb, 0xdf, 0xfe, 0xff, 0xff, 0xf7, 0xef, 0x7f, 0xff, 0x7d, 0xff, 0xbf, 0xfd, 0xfa, 0xff,
    0xcf, 0xbf, 0xff, 0xff, 0xfa, 0xdf, 0xff, 0xf7, 0xef, 0xf7, 0xff, 0x7f, 0xff, 0xfd, 0xfd, 0xbb, 0xff, 0xde, 0xbf, 0xef,
    0xff, 0xfe, 0xff, 0xfb, 0xd7, 0xef, 0xff, 0xff, 0x77, 0xff, 0x7f, 0xfd, 0xf9, 0xff, 0x9f, 0xbf, 0xfe, 0xff, 0xee, 0xff,
    0xff, 0xf7, 0xeb, 0xdf, 0xff, 0x7f, 0xff, 0xf7, 0xfd, 0x7b, 0xff, 0xdd, 0xbf, 0xbf, 0xff, 0xfe, 0xff, 0xef, 0xf7, 0xef,
    0xff, 0xfb, 0x5f, 0xff, 0xff, 0xfd, 0xf3, 0xff, 0x5f, 0xbf, 0xfd, 0xff, 0xbe, 0xff, 0xfe, 0xf7, 0xef, 0xff, 0xff, 0x7f,
    0xfb, 0xdf, 0xfd, 0xfb, 0xff, 0xd7, 0xbf, 0x7f, 0xff, 0xfc, 0xff, 0xbf, 0xf7, 0xee, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xf9,
    0xdb, 0xff, 0xdf, 0xbf, 0xf7, 0xff, 0x7e, 0xff, 0xfd, 0xf7, 0xaf, 0xff, 0xfe, 0x7f, 0xef, 0xff, 0xfd, 0xfb, 0xfb, 0xdf,
    0xbf, 0xff, 0xff, 0xf6, 0xff, 0x7f, 0xf7, 0xed, 0xff, 0xbf, 0x7f, 0xfe, 0xff, 0xed, 0xfb, 0xff, 0xdf, 0xbb, 0xdf, 0xff,
    0xfe, 0xff, 0xf7, 0xf7, 0x6f, 0xff, 0xfd, 0x7f, 0xbf, 0xff, 0xfc, 0xfb, 0xef, 0xdf, 0xbf, 0xff, 0xfb, 0xde, 0xff, 0xff,
    0xf7, 0xe7, 0xff, 0x7f, 0x7f, 0xfd, 0xff, 0xbd, 0xfb, 0xfe, 0xdf, 0xaf, 0xff, 0xff, 0xfe, 0xfb, 0xdf, 0xf7, 0xef, 0xff,
    0xf7, 0x7f, 0x7f, 0xff, 0xfd, 0xfb, 0xbf, 0xdf, 0xbe, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xf3, 0xcf, 0xff, 0xff, 0x7f, 0xf7,
    0xff, 0x7d, 0xfb, 0xfd, 0xdf, 0xbf, 0xff, 0xfe, 0xfe, 0xef, 0xff, 0xf7, 0xef, 0xfb, 0xdf, 0x7f, 0xff, 0xff, 0xf5, 0xfb,
    0x7f, 0xdf, 0xbd, 0xff, 0xbf, 0xfe, 0xfe, 0xff, 0xe7, 0xef, 0xff, 0xff, 0x7b, 0xdf, 0xff, 0xfd, 0xfb, 0xf7, 0xdf, 0x3f,
    0xff, 0xfd, 0xfe, 0xbf, 0xff, 0xf6, 0xef, 0xef, 0xff, 0x7f, 0xff, 0xfb, 0xdd, 0xfb, 0xff, 0xdf, 0xb7, 0xff, 0x7f, 0xfe,
    0xfd, 0xff, 0xb7, 0xef, 0xfe, 0xff, 0x6f, 0xff, 0xff, 0xfd, 0xfb, 0xdf, 0xdf, 0xbf, 0xff, 0xf7, 0xfe, 0x7f, 0xff, 0xf5,
    0xef, 0xbf, 0xff, 0x7e, 0xff, 0xef, 0xfd, 0xfb, 0xff, 0xdb, 0x9f, 0xff, 0xff, 0xfe, 0xf7, 0xff, 0x77, 0xef, 0xfd, 0xff,
    0x3f, 0xff, 0xfe, 0xfd, 0xeb, 0xff, 0xdf, 0xbf, 0xfb, 0xdf, 0xfe, 0xff, 0xff, 0xf7, 0xef, 0x7f, 0xff, 0x7d, 0xff, 0xbf,
    0xfd, 0xfa, 0xff, 0xcf, 0xbf, 0xff, 0xff, 0xfa, 0xdf, 0xff, 0xf7, 0xef, 0xf7, 0xff, 0x7f, 0xff, 0xfd, 0xfd, 0xbb, 0xff,
    0xde, 0xbf, 0xef, 0xff, 0xfe, 0xff, 0xfb, 0xd7, 0xef, 0xff, 0xff, 0x77, 0xff, 0x7f, 0xfd, 0xf9, 0xff, 0x9f, 0xbf, 0xfe,
    0xff, 0xee, 0xff, 0xff, 0xf7, 0xeb, 0xdf, 0xff, 0x7f, 0xff, 0xf7, 0xfd, 0x7b, 0xff, 0xdd, 0xbf, 0xbf, 0xff, 0xfe, 0xff,
    0xef, 0xf7, 0xef, 0xff, 0xfb, 0x5f, 0xff, 0xff, 0xfd, 0xf3, 0xff, 0x5f, 0xbf, 0xfd, 0xff, 0xbe, 0xff, 0xfe, 0xf7, 0xef,
    0xff, 0xff, 0x7f, 0xfb, 0xdf, 0xfd, 0xfb, 0xff, 0xd7, 0xbf, 0x7f, 0xff, 0xfc, 0xff, 0xbf, 0xf7, 0xee, 0xff, 0xef, 0x7f,
    0xff, 0xff, 0xf9, 0xdb, 0xff, 0xdf, 0xbf, 0xf7, 0xff, 0x7e, 0xff, 0xfd, 0xf7, 0xaf, 0xff, 0xfe, 0x7f, 0xef, 0xff, 0xfd,
    0xfb, 0xfb, 0xdf, 0xbf, 0xff, 0xff, 0xf6, 0xff, 0x7f, 0xf7, 0xed, 0xff, 0xbf, 0x7f, 0xfe, 0xff, 0xed, 0xfb, 0xff, 0xdf,
    0xbb, 0xdf, 0xff, 0xfe, 0xff, 0xf7, 0xf7, 0x6f, 0xff, 0xfd, 0x7f, 0xbf, 0xff, 0xfc, 0xfb, 0xef, 0xdf, 0xbf, 0xff, 0xfb,
    0xde, 0xff, 0xff, 0xf7, 0xe7, 0xff, 0x7f, 0x7f, 0xfd, 0xff, 0xbd, 0xfb, 0xfe, 0xdf, 0xaf, 0xff, 0xff, 0xfe, 0xfb, 0xdf,
    0xf7, 0xef, 0xff, 0xf7, 0x7f, 0x7f, 0xff, 0xfd, 0xfb, 0xbf, 0xdf, 0xbe, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xf3, 0xcf, 0xff,
    0xff, 0x7f, 0xf7, 0xff, 0x7d, 0xfb, 0xfd, 0xdf, 0xbf, 0xff, 0xfe, 0xfe, 0xef, 0xff, 0xf7, 0xef, 0xfb, 0xdf, 0x7f, 0xff,
    0xff, 0xf5, 0xfb, 0x7f, 0xdf, 0xbd, 0xff, 0xbf, 0xfe, 0xfe, 0xff, 0xe7, 0xef, 0xff, 0xff, 0x7b, 0xdf, 0xff, 0xfd, 0xfb,
    0xf7, 0xdf, 0x3f, 0xff, 0xfd, 0xfe, 0xbf, 0xff, 0xf6, 0xef, 0xef, 0xff, 0x7f, 0xff, 0xfb, 0xdd, 0xfb, 0xff, 0xdf, 0xb7,
    0xff, 0x7f, 0xfe, 0xfd, 0xff, 0xb7, 0xef, 0xfe, 0xff, 0x6f, 0xff, 0xff, 0xfd, 0xfb, 0xdf, 0xdf, 0xbf, 0xff, 0xf7, 0xfe,
    0x7f, 0xff, 0xf5, 0xef, 0xbf, 0xff, 0x7e, 0xff, 0xef, 0xfd, 0xfb, 0xff, 0xdb, 0x9f, 0xff, 0xff, 0xfe, 0xf7, 0xff, 0x77,
    0xef, 0xfd, 0xff, 0x3f, 0xff, 0xfe, 0xfd, 0xeb, 0xff, 0xdf, 0xbf, 0xfb, 0xdf, 0xfe, 0xff, 0xff, 0xf7, 0xef, 0x7f, 0xff,
    0x7d, 0xff, 0xbf, 0xfd, 0xfa, 0xff, 0xcf, 0xbf, 0xff, 0xff, 0xfa, 0xdf, 0xff, 0xf7, 0xef, 0xf7, 0xff, 0x7f, 0xff, 0xfd,
    0xfd, 0xbb, 0xff, 0xde, 0xbf, 0xef, 0xff, 0xfe, 0xff, 0xfb, 0xd7, 0xef, 0xff, 0xff, 0x77, 0xff, 0x7f, 0xfd, 0xf9, 0xff,
    0x9f, 0xbf, 0xfe, 0xff, 0xee, 0xff, 0xff, 0xf7, 0xeb, 0xdf, 0xff, 0x7f, 0xff, 0xf7, 0xfd, 0x7b, 0xff, 0xdd, 0xbf, 0xbf,
    0xff, 0xfe, 0xff, 0xef, 0xf7, 0xef, 0xff, 0xfb, 0x5f, 0xff, 0xff, 0xfd, 0xf3, 0xff, 0x5f, 0xbf, 0xfd, 0xff, 0xbe, 0xff,
    0xfe, 0xf7, 0xef, 0xff, 0xff, 0x7f, 0xfb, 0xdf, 0xfd, 0xfb, 0xff, 0xd7, 0xbf, 0x7f, 0xff, 0xfc, 0xff, 0xbf, 0xf7, 0xee,
    0xff, 0xef, 0x7f, 0xff, 0xff, 0xf9, 0xdb, 0xff, 0xdf, 0xbf, 0xf7, 0xff, 0x7e, 0xff, 0xfd, 0xf7, 0xaf, 0xff, 0xfe, 0x7f,
    0xef, 0xff, 0xfd, 0xfb, 0xfb, 0xdf, 0xbf, 0xff, 0xff, 0xf6, 0xff, 0x7f, 0xf7, 0xed, 0xff, 0xbf, 0x7f, 0xfe, 0xff, 0xed,
    0xfb, 0xff, 0xdf, 0xbb, 0xdf, 0xff, 0xfe, 0xff, 0xf7, 0xf7, 0x6f, 0xff, 0xfd, 0x7f, 0xbf, 0xff, 0xfc, 0xfb, 0xef, 0xdf,
    0xbf, 0xff, 0xfb, 0xde, 0xff, 0xff, 0xf7, 0xe7, 0xff, 0x7f, 0x7f, 0xfd, 0xff, 0xbd, 0xfb, 0xfe, 0xdf, 0xaf, 0xff, 0xff,
    0xfe, 0xfb, 0xdf, 0xf7, 0xef, 0xff, 0xf7, 0x7f, 0x7f, 0xff, 0xfd, 0xfb, 0xbf, 0xdf, 0xbe, 0xff, 0xef, 0xfe, 0xff, 0xff,
    0xf3, 0xcf, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0x7d, 0xfb, 0xfd, 0xdf, 0xbf, 0xff, 0xfe, 0xfe, 0xef, 0xff, 0xf7, 0xef, 0xfb,
    0xdf, 0x7f, 0xff, 0xff, 0xf5, 0xfb, 0x7f, 0xdf, 0xbd, 0xff, 0xbf, 0xfe, 0xfe, 0xff, 0xe7, 0xef, 0xff, 0xff, 0x7b, 0xdf,
    0xff, 0xfd, 0xfb, 0xf7, 0xdf, 0x3f, 0xff, 0xfd, 0xfe, 0xbf, 0xff, 0xf6, 0xef, 0xef, 0xff, 0x7f, 0xff, 0xfb, 0xdd, 0xfb,
    0xff, 0xdf, 0xb7, 0xff, 0x7f, 0xfe, 0xfd, 0xff, 0xb7, 0xef, 0xfe, 0xff, 0x6f, 0xff, 0xff, 0xfd, 0xfb, 0xdf, 0xdf, 0xbf,
    0xff, 0xf7, 0xfe, 0x7f, 0xff, 0xf5, 0xef, 0xbf, 0xff, 0x7e, 0xff, 0xef, 0xfd, 0xfb, 0xff, 0xdb, 0x9f, 0xff, 0xff, 0xfe,
    0xf7, 0xff, 0x77, 0xef, 0xfd, 0xff, 0x3f, 0xff, 0xfe, 0xfd, 0xeb, 0xff, 0xdf, 0xbf, 0xfb, 0xdf, 0xfe, 0xff, 0xff, 0xf7,
    0xef, 0x7f, 0xff, 0x7d, 0xff, 0xbf, 0xfd, 0xfa, 0xff, 0xcf, 0xbf, 0xff, 0xff, 0xfa, 0xdf, 0xff, 0xf7, 0xef, 0xf7, 0xff,
    0x7f, 0xff, 0xfd, 0xfd, 0xbb, 0xff, 0xde, 0xbf, 0xef, 0xff, 0xfe, 0xff, 0xfb, 0xd7, 0xef, 0xff, 0xff, 0x77, 0xff, 0x7f,
    0xfd, 0xf9, 0xff, 0x9f, 0xbf, 0xfe, 0xff, 0xee, 0xff, 0xff, 0xf7, 0xeb, 0xdf, 0xff, 0x7f, 0xff, 0xf7, 0xfd, 0x7b, 0xff,
    0xdd, 0xbf, 0xbf, 0xff, 0xfe, 0xff, 0xef, 0xf7, 0xef, 0xff, 0xfb, 0x5f, 0xff, 0xff, 0xfd, 0xf3, 0xff, 0x5f, 0xbf, 0xfd,
    0xff, 0xbe, 0xff, 0xfe, 0xf7, 0xef, 0xff, 0xff, 0x7f, 0xfb, 0xdf, 0xfd, 0xfb, 0xff, 0xd7, 0xbf, 0x7f, 0xff, 0xfc, 0xff,
    0xbf, 0xf7, 0xee, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xf9, 0xdb, 0xff, 0xdf, 0xbf, 0xf7, 0xff, 0x7e, 0xff, 0xfd, 0xf7, 0xaf,
    0xff, 0xfe, 0x7f, 0xef, 0xff, 0xfd, 0xfb, 0xfb, 0xdf, 0xbf, 0xff, 0xff, 0xf6, 0xff, 0x7f, 0xf7, 0xed, 0xff, 0xbf, 0x7f,
    0xfe, 0xff, 0xed, 0xfb, 0xff, 0xdf, 0xbb, 0xdf, 0xff, 0xfe, 0xff, 0xf7, 0xf7, 0x6f, 0xff, 0xfd, 0x7f, 0xbf, 0xff, 0xfc,
    0xfb, 0xef, 0xdf, 0xbf, 0xff, 0xfb, 0xde, 0xff, 0xff, 0xf7, 0xe7, 0xff, 0x7f, 0x7f, 0xfd, 0xff, 0xbd, 0xfb, 0xfe, 0xdf,
    0xaf, 0xff, 0xff, 0xfe, 0xfb, 0xdf, 0xf7, 0xef, 0xff, 0xf7, 0x7f, 0x7f, 0xff, 0xfd, 0xfb, 0xbf, 0xdf, 0xbe, 0xff, 0xef,
    0xfe, 0xff, 0xff, 0xf3, 0xcf, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0x7d, 0xfb, 0xfd, 0xdf, 0xbf, 0xff, 0xfe, 0xfe, 0xef, 0xff,
    0xf7, 0xef, 0xfb, 0xdf, 0x7f, 0xff, 0xff, 0xf5, 0xfb, 0x7f, 0xdf, 0xbd, 0xff, 0xbf, 0xfe, 0xfe, 0xff, 0xe7, 0xef, 0xff,
    0xff, 0x7b, 0xdf, 0xff, 0xfd, 0xfb, 0xf7, 0xdf, 0x3f, 0xff, 0xfd, 0xfe, 0xbf, 0xff, 0xf6, 0xef, 0xef, 0xff, 0x7f, 0xff,
    0xfb, 0xdd, 0xfb, 0xff, 0xdf, 0xb7, 0xff, 0x7f, 0xfe, 0xfd, 0xff, 0xb7, 0xef, 0xfe, 0xff, 0x6f, 0xff, 0xff, 0xfd, 0xfb,
    0xdf, 0xdf, 0xbf, 0xff, 0xf7, 0xfe, 0x7f, 0xff, 0xf5, 0xef, 0xbf, 0xff, 0x7e, 0xff, 0xef, 0xfd, 0xfb, 0xff, 0xdb, 0x9f,
    0xff, 0xff, 0xfe, 0xf7, 0xff, 0x77, 0xef, 0xfd, 0xff, 0x3f, 0xff, 0xfe, 0xfd, 0xeb, 0xff, 0xdf, 0xbf, 0xfb, 0xdf, 0xfe,
    0xff, 0xff, 0xf7, 0xef, 0x7f, 0xff, 0x7d, 0xff, 0xbf, 0xfd, 0xfa, 0xff, 0xcf, 0xbf, 0xff, 0xff, 0xfa, 0xdf, 0xff, 0xf7,
    0xef, 0xf7, 0xff, 0x7f, 0xff, 0xfd, 0xfd, 0xbb, 0xff, 0xde, 0xbf, 0xef, 0xff, 0xfe, 0xff, 0xfb, 0xd7, 0xef, 0xff, 0xff,
    0x77, 0xff, 0x7f, 0xfd, 0xf9, 0xff, 0x9f, 0xbf, 0xfe, 0xff, 0xee, 0xff, 0xff, 0xf7, 0xeb, 0xdf, 0xff, 0x7f, 0xff, 0xf7,
    0xfd, 0x7b, 0xff, 0xdd, 0xbf, 0xbf, 0xff, 0xfe, 0xff, 0xef, 0xf7, 0xef, 0xff, 0xfb, 0x5f, 0xff, 0xff, 0xfd, 0xf3, 0xff,
    0x5f, 0xbf, 0xfd, 0xff, 0xbe, 0xff, 0xfe, 0xf7, 0xef, 0xff, 0xff, 0x7f, 0xfb, 0xdf, 0xfd, 0xfb, 0xff, 0xd7, 0xbf, 0x7f,
    0xff, 0xfc, 0xff, 0xbf, 0xf7, 0xee, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xf9, 0xdb, 0xff, 0xdf, 0xbf, 0xf7, 0xff, 0x7e, 0xff,
    0xfd, 0xf7, 0xaf, 0xff, 0xfe, 0x7f, 0xef, 0xff, 0xfd, 0xfb, 0xfb, 0xdf, 0xbf, 0xff, 0xff, 0xf6, 0xff, 0x7f, 0xf7, 0xed,
    0xff, 0xbf, 0x7f, 0xfe, 0xff, 0xed, 0xfb, 0xff, 0xdf, 0xbb, 0xdf, 0xff, 0xfe, 0xff, 0xf7, 0xf7, 0x6f, 0xff, 0xfd, 0x7f,
    0xbf, 0xff, 0xfc, 0xfb, 0xef, 0xdf, 0xbf, 0xff, 0xfb, 0xde, 0xff, 0xff, 0xf7, 0xe7, 0xff, 0x7f, 0x7f, 0xfd, 0xff, 0xbd,
    0xfb, 0xfe, 0xdf, 0xaf, 0xff, 0xff, 0xfe, 0xfb, 0xdf, 0xf7, 0xef, 0xff, 0xf7, 0x7f, 0x7f, 0xff, 0xfd, 0xfb, 0xbf, 0xdf,
    0xbe, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xf3, 0xcf, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0x7d, 0xfb, 0xfd, 0xdf, 0xbf, 0xff, 0xfe,
    0xfe, 0xef, 0xff, 0xf7, 0xef, 0xfb, 0xdf, 0x7f, 0xff, 0xff, 0xf5, 0xfb, 0x7f, 0xdf, 0xbd, 0xff, 0xbf, 0xfe, 0xfe, 0xff,
    0xe7, 0xef, 0xff, 0xff, 0x7b, 0xdf, 0xff, 0xfd, 0xfb, 0xf7, 0xdf, 0x3f, 0xff, 0xfd, 0xfe, 0xbf, 0xff, 0xf6, 0xef, 0xef,
    0xff, 0x7f, 0xff, 0xfb, 0xdd, 0xfb, 0xff, 0xdf, 0xb7, 0xff, 0x7f, 0xfe, 0xfd, 0xff, 0xb7, 0xef, 0xfe, 0xff, 0x6f, 0xff,
    0xff, 0xfd, 0xfb, 0xdf, 0xdf, 0xbf, 0xff, 0xf7, 0xfe, 0x7f, 0xff, 0xf5, 0xef, 0xbf, 0xff, 0x7e, 0xff, 0xef, 0xfd, 0xfb,
    0xff, 0xdb, 0x9f, 0xff, 0xff, 0xfe, 0xf7, 0xff, 0x77, 0xef, 0xfd, 0xff, 0x3f, 0xff, 0xfe, 0xfd, 0xeb, 0xff, 0xdf, 0xbf,
    0xfb, 0xdf, 0xfe, 0xff, 0xff, 0xf7, 0xef, 0x7f, 0xff, 0x7d, 0xff, 0xbf, 0xfd, 0xfa, 0xff, 0xcf, 0xbf, 0xff, 0xff, 0xfa,
    0xdf, 0xff, 0xf7, 0xef, 0xf7, 0xff, 0x7f, 0xff, 0xfd, 0xfd, 0xbb, 0xff, 0xde, 0xbf, 0xef, 0xff, 0xfe, 0xff, 0xfb, 0xd7,
    0xef, 0xff, 0xff, 0x77, 0xff, 0x7f, 0xfd, 0xf9, 0xff, 0x9f, 0xbf, 0xfe, 0xff, 0xee, 0xff, 0xff, 0xf7, 0xeb, 0xdf, 0xff,
    0x7f, 0xff, 0xf7, 0xfd, 0x7b, 0xff, 0xdd, 0xbf, 0xbf, 0xff, 0xfe, 0xff, 0xef, 0xf7, 0xef, 0xff, 0xfb, 0x5f, 0xff, 0xff,
    0xfd, 0xf3, 0xff, 0x5f, 0xbf, 0xfd, 0xff, 0xbe, 0xff, 0xfe, 0xf7, 0xef, 0xff, 0xff, 0x7f, 0xfb, 0xdf, 0xfd, 0xfb, 0xff,
    0xd7, 0xbf, 0x7f, 0xff, 0xfc, 0xff, 0xbf, 0xf7, 0xee, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xf9, 0xdb, 0xff, 0xdf, 0xbf, 0xf7,
    0xff, 0x7e, 0xff, 0xfd, 0xf7, 0xaf, 0xff, 0xfe, 0x7f, 0xef, 0xff, 0xfd, 0xfb, 0xfb, 0xdf, 0xbf, 0xff, 0xff, 0xf6, 0xff,
    0x7f, 0xf7, 0xed, 0xff, 0xbf, 0x7f, 0xfe, 0xff, 0xed, 0xfb, 0xff, 0xdf, 0xbb, 0xdf, 0xff, 0xfe, 0xff, 0xf7, 0xf7, 0x6f,
    0xff, 0xfd, 0x7f, 0xbf, 0xff, 0xfc, 0xfb, 0xef, 0xdf, 0xbf, 0xff, 0xfb, 0xde, 0xff, 0xff, 0xf7, 0xe7, 0xff, 0x7f, 0x7f,
    0xfd, 0xff, 0xbd, 0xfb, 0xfe, 0xdf, 0xaf, 0xff, 0xff, 0xfe, 0xfb, 0xdf, 0xf7, 0xef, 0xff, 0xf7, 0x7f, 0x7f, 0xff, 0xfd,
    0xfb, 0xbf, 0xdf, 0xbe, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xf3 },
  { 0x3f, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xbf, 0xff, 0xf7, 0x7f, 0xdf, 0xff, 0xef, 0xfe, 0xef, 0xff, 0xf7, 0xdf, 0xfb, 0xff,
    0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x7f, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xbf, 0xfe, 0xef, 0xff, 0xdf,
    0xdf, 0xef, 0xff, 0xff, 0xff, 0xf5, 0xbf, 0xfb, 0xff, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xfe, 0x7f, 0xfe,
    0xef, 0xff, 0xff, 0xdf, 0xbf, 0xff, 0xff, 0xff, 0xdd, 0xbf, 0xef, 0xff, 0xff, 0xff, 0xf3, 0xff, 0xfb, 0xf7, 0x7f, 0xff,
    0xfd, 0xff, 0xfe, 0xef, 0xff, 0xff, 0xde, 0x7f, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xbf, 0xff, 0xff, 0xff, 0xdb, 0xff, 0xef,
    0xf7, 0x7f, 0xff, 0xf7, 0xff, 0xfa, 0xef, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xbe, 0x7f, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0xbf, 0xf7, 0x7f, 0xff, 0xdf, 0xff, 0xee, 0xef, 0xff, 0xff, 0xd7, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xbd, 0xff,
    0xff, 0xff, 0xff, 0xfb, 0xfe, 0x7f, 0xf7, 0x7f, 0xff, 0xff, 0xff, 0xbe, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xef, 0xff, 0xff,
    0xfd, 0xb7, 0xff, 0xfb, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xfe, 0x7e, 0xef, 0xff, 0xff, 0xdf, 0xff,
    0xbf, 0xff, 0xff, 0xfd, 0x9f, 0xff, 0xef, 0xff, 0xff, 0xfb, 0xf7, 0xff, 0xf3, 0x7f, 0xff, 0xff, 0xfd, 0xfe, 0xef, 0xff,
    0xff, 0xdf, 0xfe, 0x7f, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xbf, 0xff, 0xff, 0xfb, 0xdf, 0xff, 0xe7, 0x7f, 0xff, 0xff, 0xf7,
    0xfe, 0xeb, 0xff, 0xff, 0xdf, 0xfd, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xfe, 0x7f, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xb7, 0x7f,
    0xff, 0xff, 0xdf, 0xfe, 0xef, 0xff, 0xff, 0xdf, 0xf7, 0xff, 0xfb, 0xff, 0xfd, 0xbf, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xff,
    0xfe, 0x77, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xaf, 0xff, 0xff, 0xdf, 0xdf, 0xff, 0xef, 0xff, 0xfd, 0xbf, 0xf7, 0xff, 0xfb,
    0xff, 0xfb, 0xff, 0xfd, 0xf7, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0x6f, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xbf,
    0xdf, 0xff, 0xef, 0xff, 0xfb, 0xff, 0xf7, 0xf7, 0x7b, 0xff, 0xff, 0xff, 0xfc, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xfe, 0x7f,
    0xff, 0xfd, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xfb, 0xff, 0xdf, 0xf7, 0x6f, 0xff, 0xff, 0xff, 0xf6, 0xef, 0xfb, 0xff, 0xdf,
    0xff, 0xfd, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xfe, 0x7f, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0x3f, 0xff, 0xff, 0xff, 0xde, 0xef,
    0xef, 0xff, 0xdf, 0xff, 0xf7, 0xff, 0xfb, 0xfd, 0xbf, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xf6, 0x7f, 0xff, 0xff,
    0xff, 0xfe, 0xef, 0xbf, 0xff, 0xdf, 0xff, 0xdf, 0xff, 0xef, 0xfd, 0xbf, 0xff, 0xf7, 0xff, 0xfb, 0xfb, 0xff, 0xff, 0xf5,
    0x7f, 0xff, 0xff, 0xff, 0xfe, 0xee, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xfd, 0xbf, 0xff, 0xdf, 0xff, 0xef, 0xfb,
    0xff, 0xff, 0xf7, 0x7f, 0xfb, 0xff, 0xff, 0xfe, 0xed, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfe, 0x7f, 0xfd, 0xbf, 0xff, 0xff,
    0xff, 0xbf, 0xfb, 0xff, 0xff, 0xd7, 0x7f, 0xef, 0xff, 0xff, 0xfe, 0xe7, 0xff, 0xfb, 0xdf, 0xff, 0xff, 0xfd, 0xff, 0xfd,
    0xbf, 0xff, 0xff, 0xfe, 0x7f, 0xfb, 0xff, 0xff, 0xf7, 0x7f, 0xbf, 0xff, 0xff, 0xfe, 0xcf, 0xff, 0xef, 0xdf, 0xff, 0xff,
    0xf7, 0xff, 0xf9, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0x7e, 0x7f, 0xff, 0xff, 0xfe, 0xef, 0xff, 0xbf,
    0xdf, 0xff, 0xff, 0xdf, 0xff, 0xed, 0xbf, 0xff, 0xff, 0xf7, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0x7d, 0xff, 0xff, 0xff, 0xfe,
    0xef, 0xfe, 0x7f, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xbd, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xeb, 0xff, 0xff, 0xf7, 0x77, 0xff,
    0xfb, 0xff, 0xfe, 0xef, 0xfd, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfe, 0x7d, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xbb, 0xff, 0xff,
    0xf7, 0x5f, 0xff, 0xef, 0xff, 0xfe, 0xef, 0xf7, 0xff, 0xdb, 0xff, 0xff, 0xff, 0xfd, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xfe,
    0x7b, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xbf, 0xff, 0xfe, 0xef, 0xdf, 0xff, 0xcf, 0xff, 0xff, 0xff, 0xf7, 0xfd, 0xbb, 0xff,
    0xff, 0xff, 0xfd, 0xfb, 0xff, 0xff, 0xf7, 0x7f, 0xfe, 0x7f, 0xff, 0xfe, 0xef, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xff, 0xdf,
    0xfd, 0xaf, 0xff, 0xff, 0xff, 0xf7, 0xfb, 0xfb, 0xff, 0xf7, 0x7f, 0xfd, 0xff, 0xff, 0xfe, 0xef, 0xff, 0xfe, 0x5f, 0xff,
    0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xdf, 0xfb, 0xef, 0xff, 0xf7, 0x7f, 0xf7, 0xff, 0xfb, 0xfe, 0xef, 0xff,
    0xfd, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xbf, 0xff, 0xf7, 0x7f, 0xdf, 0xff, 0xef,
    0xfe, 0xef, 0xff, 0xf7, 0xdf, 0xfb, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x7f, 0xff, 0xf7, 0x7f,
    0xff, 0xff, 0xbf, 0xfe, 0xef, 0xff, 0xdf, 0xdf, 0xef, 0xff, 0xff, 0xff, 0xf5, 0xbf, 0xfb, 0xff, 0xff, 0xff, 0xf9, 0xff,
    0xff, 0xf7, 0x7f, 0xff, 0xfe, 0x7f, 0xfe, 0xef, 0xff, 0xff, 0xdf, 0xbf, 0xff, 0xff, 0xff, 0xdd, 0xbf, 0xef, 0xff, 0xff,
    0xff, 0xf3, 0xff, 0xfb, 0xf7, 0x7f, 0xff, 0xfd, 0xff, 0xfe, 0xef, 0xff, 0xff, 0xde, 0x7f, 0xff, 0xff, 0xff, 0xfd, 0xbf,
    0xbf, 0xff, 0xff, 0xff, 0xdb, 0xff, 0xef, 0xf7, 0x7f, 0xff, 0xf7, 0xff, 0xfa, 0xef, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xbe, 0x7f, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xbf, 0xf7, 0x7f, 0xff, 0xdf, 0xff, 0xee, 0xef, 0xff, 0xff, 0xd7,
    0xff, 0xfb, 0xff, 0xff, 0xfd, 0xbd, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfe, 0x7f, 0xf7, 0x7f, 0xff, 0xff, 0xff, 0xbe, 0xef,
    0xff, 0xff, 0xdf, 0xff, 0xef, 0xff, 0xff, 0xfd, 0xb7, 0xff, 0xfb, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xf7, 0x7f, 0xff, 0xff,
    0xfe, 0x7e, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0x9f, 0xff, 0xef, 0xff, 0xff, 0xfb, 0xf7, 0xff, 0xf3,
    0x7f, 0xff, 0xff, 0xfd, 0xfe, 0xef, 0xff, 0xff, 0xdf, 0xfe, 0x7f, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xbf, 0xff, 0xff, 0xfb,
    0xdf, 0xff, 0xe7, 0x7f, 0xff, 0xff, 0xf7, 0xfe, 0xeb, 0xff, 0xff, 0xdf, 0xfd, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xfe, 0x7f,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xb7, 0x7f, 0xff, 0xff, 0xdf, 0xfe, 0xef, 0xff, 0xff, 0xdf, 0xf7, 0xff, 0xfb, 0xff, 0xfd,
    0xbf, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfe, 0x77, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xaf, 0xff, 0xff, 0xdf, 0xdf, 0xff,
    0xef, 0xff, 0xfd, 0xbf, 0xf7, 0xff, 0xfb, 0xff, 0xfb, 0xff, 0xfd, 0xf7, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0x6f, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xbf, 0xdf, 0xff, 0xef, 0xff, 0xfb, 0xff, 0xf7, 0xf7, 0x7b, 0xff, 0xff, 0xff, 0xfc,
    0xef, 0xff, 0xff, 0xdf, 0xff, 0xfe, 0x7f, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xfb, 0xff, 0xdf, 0xf7, 0x6f, 0xff,
    0xff, 0xff, 0xf6, 0xef, 0xfb, 0xff, 0xdf, 0xff, 0xfd, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xfe, 0x7f, 0xff, 0xfb, 0xff, 0xff,
    0xf7, 0x3f, 0xff, 0xff, 0xff, 0xde, 0xef, 0xef, 0xff, 0xdf, 0xff, 0xf7, 0xff, 0xfb, 0xfd, 0xbf, 0xff, 0xfd, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xf6, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xef, 0xbf, 0xff, 0xdf, 0xff, 0xdf, 0xff, 0xef, 0xfd, 0xbf, 0xff,
    0xf7, 0xff, 0xfb, 0xfb, 0xff, 0xff, 0xf5, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xee, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xbf,
    0xfd, 0xbf, 0xff, 0xdf, 0xff, 0xef, 0xfb, 0xff, 0xff, 0xf7, 0x7f, 0xfb, 0xff, 0xff, 0xfe, 0xed, 0xff, 0xff, 0xdf, 0xff,
    0xff, 0xfe, 0x7f, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xbf, 0xfb, 0xff, 0xff, 0xd7, 0x7f, 0xef, 0xff, 0xff, 0xfe, 0xe7, 0xff,
    0xfb, 0xdf, 0xff, 0xff, 0xfd, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xfe, 0x7f, 0xfb, 0xff, 0xff, 0xf7, 0x7f, 0xbf, 0xff, 0xff,
    0xfe, 0xcf, 0xff, 0xef, 0xdf, 0xff, 0xff, 0xf7, 0xff, 0xf9, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0x7e,
    0x7f, 0xff, 0xff, 0xfe, 0xef, 0xff, 0xbf, 0xdf, 0xff, 0xff, 0xdf, 0xff, 0xed, 0xbf, 0xff, 0xff, 0xf7, 0xff, 0xfb, 0xff,
    0xff, 0xf7, 0x7d, 0xff, 0xff, 0xff, 0xfe, 0xef, 0xfe, 0x7f, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xbd, 0xbf, 0xff, 0xff, 0xdf,
    0xff, 0xeb, 0xff, 0xff, 0xf7, 0x77, 0xff, 0xfb, 0xff, 0xfe, 0xef, 0xfd, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfe, 0x7d, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xbb, 0xff, 0xff, 0xf7, 0x5f, 0xff, 0xef, 0xff, 0xfe, 0xef, 0xf7, 0xff, 0xdb, 0xff, 0xff, 0xff,
    0xfd, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xfe, 0x7b, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xbf, 0xff, 0xfe, 0xef, 0xdf, 0xff, 0xcf,
    0xff, 0xff, 0xff, 0xf7, 0xfd, 0xbb, 0xff, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xff, 0xf7, 0x7f, 0xfe, 0x7f, 0xff, 0xfe, 0xef,
    0xff, 0xff, 0x9f, 0xff, 0xff, 0xff, 0xdf, 0xfd, 0xaf, 0xff, 0xff, 0xff, 0xf7, 0xfb, 0xfb, 0xff, 0xf7, 0x7f, 0xfd, 0xff,
    0xff, 0xfe, 0xef, 0xff, 0xfe, 0x5f, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xdf, 0xfb, 0xef, 0xff, 0xf7,
    0x7f, 0xf7, 0xff, 0xfb, 0xfe, 0xef, 0xff, 0xfd, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xfb,
    0xbf, 0xff, 0xf7, 0x7f, 0xdf, 0xff, 0xef, 0xfe, 0xef, 0xff, 0xf7, 0xdf, 0xfb, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xfa, 0x7f, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xbf, 0xfe, 0xef, 0xff, 0xdf, 0xdf, 0xef, 0xff, 0xff, 0xff, 0xf5,
    0xbf, 0xfb, 0xff, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xfe, 0x7f, 0xfe, 0xef, 0xff, 0xff, 0xdf, 0xbf, 0xff,
    0xff, 0xff, 0xdd, 0xbf, 0xef, 0xff, 0xff, 0xff, 0xf3, 0xff, 0xfb, 0xf7, 0x7f, 0xff, 0xfd, 0xff, 0xfe, 0xef, 0xff, 0xff,
    0xde, 0x7f, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xbf, 0xff, 0xff, 0xff, 0xdb, 0xff, 0xef, 0xf7, 0x7f, 0xff, 0xf7, 0xff, 0xfa,
    0xef, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xbe, 0x7f, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xbf, 0xf7, 0x7f, 0xff,
    0xdf, 0xff, 0xee, 0xef, 0xff, 0xff, 0xd7, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xbd, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfe, 0x7f,
    0xf7, 0x7f, 0xff, 0xff, 0xff, 0xbe, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xef, 0xff, 0xff, 0xfd, 0xb7, 0xff, 0xfb, 0xff, 0xff,
    0xfb, 0xfd, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xfe, 0x7e, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0x9f, 0xff,
    0xef, 0xff, 0xff, 0xfb, 0xf7, 0xff, 0xf3, 0x7f, 0xff, 0xff, 0xfd, 0xfe, 0xef, 0xff, 0xff, 0xdf, 0xfe, 0x7f, 0xff, 0xff,
    0xfd, 0xbf, 0xff, 0xbf, 0xff, 0xff, 0xfb, 0xdf, 0xff, 0xe7, 0x7f, 0xff, 0xff, 0xf7, 0xfe, 0xeb, 0xff, 0xff, 0xdf, 0xfd,
    0xff, 0xff, 0xff, 0xfd, 0xbf, 0xfe, 0x7f, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xb7, 0x7f, 0xff, 0xff, 0xdf, 0xfe, 0xef, 0xff,
    0xff, 0xdf, 0xf7, 0xff, 0xfb, 0xff, 0xfd, 0xbf, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfe, 0x77, 0x7f, 0xff, 0xff, 0xff,
    0xfe, 0xaf, 0xff, 0xff, 0xdf, 0xdf, 0xff, 0xef, 0xff, 0xfd, 0xbf, 0xf7, 0xff, 0xfb, 0xff, 0xfb, 0xff, 0xfd, 0xf7, 0x7f,
    0xff, 0xff, 0xff, 0xfe, 0x6f, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xbf, 0xdf, 0xff, 0xef, 0xff, 0xfb, 0xff,
    0xf7, 0xf7, 0x7b, 0xff, 0xff, 0xff, 0xfc, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xfe, 0x7f, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xbf,
    0xff, 0xfb, 0xff, 0xdf, 0xf7, 0x6f, 0xff, 0xff, 0xff, 0xf6, 0xef, 0xfb, 0xff, 0xdf, 0xff, 0xfd, 0xff, 0xff, 0xfd, 0xbf,
    0xff, 0xfe, 0x7f, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0x3f, 0xff, 0xff, 0xff, 0xde, 0xef, 0xef, 0xff, 0xdf, 0xff, 0xf7, 0xff,
    0xfb, 0xfd, 0xbf, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xf6, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xef, 0xbf, 0xff, 0xdf,
    0xff, 0xdf, 0xff, 0xef, 0xfd, 0xbf, 0xff, 0xf7, 0xff, 0xfb, 0xfb, 0xff, 0xff, 0xf5, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xee,
    0x7f, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xfd, 0xbf, 0xff, 0xdf, 0xff, 0xef, 0xfb, 0xff, 0xff, 0xf7, 0x7f, 0xfb, 0xff,
    0xff, 0xfe, 0xed, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfe, 0x7f, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xbf, 0xfb, 0xff, 0xff, 0xd7,
    0x7f, 0xef, 0xff, 0xff, 0xfe, 0xe7, 0xff, 0xfb, 0xdf, 0xff, 0xff, 0xfd, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xfe, 0x7f, 0xfb,
    0xff, 0xff, 0xf7, 0x7f, 0xbf, 0xff, 0xff, 0xfe, 0xcf, 0xff, 0xef, 0xdf, 0xff, 0xff, 0xf7, 0xff, 0xf9, 0xbf, 0xff, 0xff,
    0xfd, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0x7e, 0x7f, 0xff, 0xff, 0xfe, 0xef, 0xff, 0xbf, 0xdf, 0xff, 0xff, 0xdf, 0xff, 0xed,
    0xbf, 0xff, 0xff, 0xf7, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0x7d, 0xff, 0xff, 0xff, 0xfe, 0xef, 0xfe, 0x7f, 0xdf, 0xff, 0xff,
    0xff, 0xff, 0xbd, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xeb, 0xff, 0xff, 0xf7, 0x77, 0xff, 0xfb, 0xff, 0xfe, 0xef, 0xfd, 0xff,
    0xdf, 0xff, 0xff, 0xff, 0xfe, 0x7d, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xbb, 0xff, 0xff, 0xf7, 0x5f, 0xff, 0xef, 0xff, 0xfe,
    0xef, 0xf7, 0xff, 0xdb, 0xff, 0xff, 0xff, 0xfd, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xfe, 0x7b, 0xff, 0xff, 0xf7, 0x7f, 0xff,
    0xbf, 0xff, 0xfe, 0xef, 0xdf, 0xff, 0xcf, 0xff, 0xff, 0xff, 0xf7, 0xfd, 0xbb, 0xff, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xff,
    0xf7, 0x7f, 0xfe, 0x7f, 0xff, 0xfe, 0xef, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xff, 0xdf, 0xfd, 0xaf, 0xff, 0xff, 0xff, 0xf7,
    0xfb, 0xfb, 0xff, 0xf7, 0x7f, 0xfd, 0xff, 0xff, 0xfe, 0xef, 0xff, 0xfe, 0x5f, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff,
    0xff, 0xff, 0xdf, 0xfb, 0xef, 0xff, 0xf7, 0x7f, 0xf7, 0xff, 0xfb, 0xfe, 0xef, 0xff, 0xfd, 0xdf, 0xff, 0xff, 0xff, 0xff,
    0xfc, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xbf, 0xff, 0xf7, 0x7f, 0xdf, 0xff, 0xef, 0xfe, 0xef, 0xff, 0xf7, 0xdf, 0xfb,
    0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x7f, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xbf, 0xfe, 0xef, 0xff,
    0xdf, 0xdf, 0xef, 0xff, 0xff, 0xff, 0xf5, 0xbf, 0xfb, 0xff, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xfe, 0x7f,
    0xfe, 0xef, 0xff, 0xff, 0xdf, 0xbf, 0xff, 0xff, 0xff, 0xdd, 0xbf, 0xef, 0xff, 0xff, 0xff, 0xf3, 0xff, 0xfb, 0xf7, 0x7f,
    0xff, 0xfd, 0xff, 0xfe, 0xef, 0xff, 0xff, 0xde, 0x7f, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xbf, 0xff, 0xff, 0xff, 0xdb, 0xff,
    0xef, 0xf7, 0x7f, 0xff, 0xf7, 0xff, 0xfa, 0xef, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xbe, 0x7f, 0xff, 0xff,
    0xff, 0xfb, 0xff, 0xbf, 0xf7, 0x7f, 0xff, 0xdf, 0xff, 0xee, 0xef, 0xff, 0xff, 0xd7, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xbd,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0xfe, 0x7f, 0xf7, 0x7f, 0xff, 0xff, 0xff, 0xbe, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xef, 0xff,
    0xff, 0xfd, 0xb7, 0xff, 0xfb, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xfe, 0x7e, 0xef, 0xff, 0xff, 0xdf,
    0xff, 0xbf, 0xff, 0xff, 0xfd, 0x9f, 0xff, 0xef, 0xff, 0xff, 0xfb, 0xf7, 0xff, 0xf3, 0x7f, 0xff, 0xff, 0xfd, 0xfe, 0xef,
    0xff, 0xff, 0xdf, 0xfe, 0x7f, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xbf, 0xff, 0xff, 0xfb, 0xdf, 0xff, 0xe7, 0x7f, 0xff, 0xff,
    0xf7, 0xfe, 0xeb, 0xff, 0xff, 0xdf, 0xfd, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xfe, 0x7f, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xb7,
    0x7f, 0xff, 0xff, 0xdf, 0xfe, 0xef, 0xff, 0xff, 0xdf, 0xf7, 0xff, 0xfb, 0xff, 0xfd, 0xbf, 0xfd, 0xff, 0xff, 0xff, 0xfb,
    0xff, 0xfe, 0x77, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xaf, 0xff, 0xff, 0xdf, 0xdf, 0xff, 0xef, 0xff, 0xfd, 0xbf, 0xf7, 0xff,
    0xfb, 0xff, 0xfb, 0xff, 0xfd, 0xf7, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0x6f, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xfd,
    0xbf, 0xdf, 0xff, 0xef, 0xff, 0xfb, 0xff, 0xf7, 0xf7, 0x7b, 0xff, 0xff, 0xff, 0xfc, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xfe,
    0x7f, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xfb, 0xff, 0xdf, 0xf7, 0x6f, 0xff, 0xff, 0xff, 0xf6, 0xef, 0xfb, 0xff,
    0xdf, 0xff, 0xfd, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xfe, 0x7f, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0x3f, 0xff, 0xff, 0xff, 0xde,
    0xef, 0xef, 0xff, 0xdf, 0xff, 0xf7, 0xff, 0xfb, 0xfd, 0xbf, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xf6, 0x7f, 0xff,
    0xff, 0xff, 0xfe, 0xef, 0xbf, 0xff, 0xdf, 0xff, 0xdf, 0xff, 0xef, 0xfd, 0xbf, 0xff, 0xf7, 0xff, 0xfb, 0xfb, 0xff, 0xff,
    0xf5, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xee, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xfd, 0xbf, 0xff, 0xdf, 0xff, 0xef,
    0xfb, 0xff, 0xff, 0xf7, 0x7f, 0xfb, 0xff, 0xff, 0xfe, 0xed, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfe, 0x7f, 0xfd, 0xbf, 0xff,
    0xff, 0xff, 0xbf, 0xfb, 0xff, 0xff, 0xd7, 0x7f, 0xef, 0xff, 0xff, 0xfe, 0xe7, 0xff, 0xfb, 0xdf, 0xff, 0xff, 0xfd, 0xff,
    0xfd, 0xbf, 0xff, 0xff, 0xfe, 0x7f, 0xfb, 0xff, 0xff, 0xf7, 0x7f, 0xbf, 0xff, 0xff, 0xfe, 0xcf, 0xff, 0xef, 0xdf, 0xff,
    0xff, 0xf7, 0xff, 0xf9, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0x7e, 0x7f, 0xff, 0xff, 0xfe, 0xef, 0xff,
    0xbf, 0xdf, 0xff, 0xff, 0xdf, 0xff, 0xed, 0xbf, 0xff, 0xff, 0xf7, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0x7d, 0xff, 0xff, 0xff,
    0xfe, 0xef, 0xfe, 0x7f, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xbd, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xeb, 0xff, 0xff, 0xf7, 0x77,
    0xff, 0xfb, 0xff, 0xfe, 0xef, 0xfd, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfe, 0x7d, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xbb, 0xff,
    0xff, 0xf7, 0x5f, 0xff, 0xef, 0xff, 0xfe, 0xef, 0xf7, 0xff, 0xdb, 0xff, 0xff, 0xff, 0xfd, 0xfd, 0xbf, 0xff, 0xff, 0xff,
    0xfe, 0x7b, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xbf, 0xff, 0xfe, 0xef, 0xdf, 0xff, 0xcf, 0xff, 0xff, 0xff, 0xf7, 0xfd, 0xbb,
    0xff, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xff, 0xf7, 0x7f, 0xfe, 0x7f, 0xff, 0xfe, 0xef, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xff,
    0xdf, 0xfd, 0xaf, 0xff, 0xff, 0xff, 0xf7, 0xfb, 0xfb, 0xff, 0xf7, 0x7f, 0xfd, 0xff, 0xff, 0xfe, 0xef, 0xff, 0xfe, 0x5f,
    0xff, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xdf, 0xfb, 0xef, 0xff, 0xf7, 0x7f, 0xf7, 0xff, 0xfb, 0xfe, 0xef,
    0xff, 0xfd, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xbf, 0xff, 0xf7, 0x7f, 0xdf, 0xff,
    0xef, 0xfe, 0xef, 0xff, 0xf7, 0xdf, 0xfb, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfa, 0x7f, 0xff, 0xf7,
    0x7f, 0xff, 0xff, 0xbf, 0xfe, 0xef, 0xff, 0xdf, 0xdf, 0xef, 0xff, 0xff, 0xff, 0xf5, 0xbf, 0xfb, 0xff, 0xff, 0xff, 0xf9,
    0xff, 0xff, 0xf7, 0x7f, 0xff, 0xfe, 0x7f, 0xfe, 0xef, 0xff, 0xff, 0xdf, 0xbf, 0xff, 0xff, 0xff, 0xdd, 0xbf, 0xef, 0xff,
    0xff, 0xff, 0xf3, 0xff, 0xfb, 0xf7, 0x7f, 0xff, 0xfd, 0xff, 0xfe, 0xef, 0xff, 0xff, 0xde, 0x7f, 0xff, 0xff, 0xff, 0xfd,
    0xbf, 0xbf, 0xff, 0xff, 0xff, 0xdb, 0xff, 0xef, 0xf7, 0x7f, 0xff, 0xf7, 0xff, 0xfa, 0xef, 0xff, 0xff, 0xdd, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xbe, 0x7f, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xbf, 0xf7, 0x7f, 0xff, 0xdf, 0xff, 0xee, 0xef, 0xff, 0xff,
    0xd7, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xbd, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfe, 0x7f, 0xf7, 0x7f, 0xff, 0xff, 0xff, 0xbe,
    0xef, 0xff, 0xff, 0xdf, 0xff, 0xef, 0xff, 0xff, 0xfd, 0xb7, 0xff, 0xfb, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xf7, 0x7f, 0xff,
    0xff, 0xfe, 0x7e, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0x9f, 0xff, 0xef, 0xff, 0xff, 0xfb, 0xf7, 0xff,
    0xf3, 0x7f, 0xff, 0xff, 0xfd, 0xfe, 0xef, 0xff, 0xff, 0xdf, 0xfe, 0x7f, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xbf, 0xff, 0xff,
    0xfb, 0xdf, 0xff, 0xe7, 0x7f, 0xff, 0xff, 0xf7, 0xfe, 0xeb, 0xff, 0xff, 0xdf, 0xfd, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xfe,
    0x7f, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xb7, 0x7f, 0xff, 0xff, 0xdf, 0xfe, 0xef, 0xff, 0xff, 0xdf, 0xf7, 0xff, 0xfb, 0xff,
    0xfd, 0xbf, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfe, 0x77, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xaf, 0xff, 0xff, 0xdf, 0xdf,
    0xff, 0xef, 0xff, 0xfd, 0xbf, 0xf7, 0xff, 0xfb, 0xff, 0xfb, 0xff, 0xfd, 0xf7, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0x6f, 0xff,
    0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xbf, 0xdf, 0xff, 0xef, 0xff, 0xfb, 0xff, 0xf7, 0xf7, 0x7b, 0xff, 0xff, 0xff,
    0xfc, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xfe, 0x7f, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xfb, 0xff, 0xdf, 0xf7, 0x6f,
    0xff, 0xff, 0xff, 0xf6, 0xef, 0xfb, 0xff, 0xdf, 0xff, 0xfd, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xfe, 0x7f, 0xff, 0xfb, 0xff,
    0xff, 0xf7, 0x3f, 0xff, 0xff, 0xff, 0xde, 0xef, 0xef, 0xff, 0xdf, 0xff, 0xf7, 0xff, 0xfb, 0xfd, 0xbf, 0xff, 0xfd, 0xff,
    0xff, 0xfb, 0xff, 0xff, 0xf6, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xef, 0xbf, 0xff, 0xdf, 0xff, 0xdf, 0xff, 0xef, 0xfd, 0xbf,
    0xff, 0xf7, 0xff, 0xfb, 0xfb, 0xff, 0xff, 0xf5, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xee, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xff,
    0xbf, 0xfd, 0xbf, 0xff, 0xdf, 0xff, 0xef, 0xfb, 0xff, 0xff, 0xf7, 0x7f, 0xfb, 0xff, 0xff, 0xfe, 0xed, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xfe, 0x7f, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xbf, 0xfb, 0xff, 0xff, 0xd7, 0x7f, 0xef, 0xff, 0xff, 0xfe, 0xe7,
    0xff, 0xfb, 0xdf, 0xff, 0xff, 0xfd, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xfe, 0x7f, 0xfb, 0xff, 0xff, 0xf7, 0x7f, 0xbf, 0xff,
    0xff, 0xfe, 0xcf, 0xff, 0xef, 0xdf, 0xff, 0xff, 0xf7, 0xff, 0xf9, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xfb, 0xff, 0xff, 0xf7,
    0x7e, 0x7f, 0xff, 0xff, 0xfe, 0xef, 0xff, 0xbf, 0xdf, 0xff, 0xff, 0xdf, 0xff, 0xed, 0xbf, 0xff, 0xff, 0xf7, 0xff, 0xfb,
    0xff, 0xff, 0xf7, 0x7d, 0xff, 0xff, 0xff, 0xfe, 0xef, 0xfe, 0x7f, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xbd, 0xbf, 0xff, 0xff,
    0xdf, 0xff, 0xeb, 0xff, 0xff, 0xf7, 0x77, 0xff, 0xfb, 0xff, 0xfe, 0xef, 0xfd, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfe, 0x7d,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xbb, 0xff, 0xff, 0xf7, 0x5f, 0xff, 0xef, 0xff, 0xfe, 0xef, 0xf7, 0xff, 0xdb, 0xff, 0xff,
    0xff, 0xfd, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xfe, 0x7b, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xbf, 0xff, 0xfe, 0xef, 0xdf, 0xff,
    0xcf, 0xff, 0xff, 0xff, 0xf7, 0xfd, 0xbb, 0xff, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xff, 0xf7, 0x7f, 0xfe, 0x7f, 0xff, 0xfe,
    0xef, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xff, 0xdf, 0xfd, 0xaf, 0xff, 0xff, 0xff, 0xf7, 0xfb, 0xfb, 0xff, 0xf7, 0x7f, 0xfd,
    0xff, 0xff, 0xfe, 0xef, 0xff, 0xfe, 0x5f, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xdf, 0xfb, 0xef, 0xff,
    0xf7, 0x7f, 0xf7, 0xff, 0xfb, 0xfe, 0xef, 0xff, 0xfd, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfc },
  { 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xe7, 0xff, 0xff, 0xfe, 0xef, 0xff, 0xdf,
    0x7f, 0xff, 0xff, 0xb7, 0xff, 0xff, 0xff, 0xff, 0xfb, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff,
    0xff, 0xff, 0xfb, 0xff, 0xf7, 0xdf, 0xff, 0xff, 0xef, 0xff, 0xcf, 0xff, 0xff, 0xfe, 0xbf, 0xff, 0xff, 0x7f, 0xff, 0xff,
    0x77, 0xff, 0xff, 0xfe, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xfb, 0xff, 0xf5, 0xff, 0xff, 0xff, 0xef,
    0xff, 0xdf, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xef, 0xff, 0xff, 0xfe, 0x7f, 0xff, 0xff, 0x7e, 0xff, 0xff, 0xf7, 0xff, 0xff,
    0xfd, 0xff, 0xfb, 0xff, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xbf, 0xef, 0xff, 0xdd, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0x7f, 0xff, 0xef, 0xfe, 0xff, 0xfe, 0xff, 0xff, 0xff, 0x7d, 0xff, 0xff, 0xf7, 0xfb, 0xff, 0xf7, 0xff, 0xfb,
    0xff, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xbf, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xde, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xfd, 0xff, 0xfe, 0xff, 0xfb, 0xff, 0x77, 0xff, 0xff, 0xf7, 0xef, 0xff, 0xdf, 0xff, 0xfb, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xff, 0xbf, 0x7f, 0xff, 0xfd, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xff, 0xfb, 0xef, 0xf7,
    0xff, 0xfe, 0xff, 0xef, 0xff, 0x5f, 0xff, 0xff, 0xf7, 0xbf, 0xff, 0xff, 0xff, 0xfb, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff,
    0xbf, 0xff, 0xff, 0xfd, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xd7, 0xff, 0xff, 0xff, 0xef, 0xef, 0xdf, 0xff, 0xfe, 0xff,
    0xbf, 0xff, 0x7f, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xfe, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xbf, 0xff, 0xfb,
    0xfd, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xef, 0xff, 0xff, 0xfe, 0xff, 0x7f, 0xff, 0x7f,
    0xfe, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xff, 0xbf, 0xff, 0xef, 0xfd, 0xdf, 0xff,
    0xff, 0xff, 0xbf, 0xff, 0xdf, 0xff, 0xff, 0xff, 0x7f, 0xef, 0xff, 0xfe, 0xfe, 0xff, 0xff, 0xff, 0x7f, 0xfd, 0xff, 0xf7,
    0xff, 0xfb, 0xff, 0xf7, 0xfb, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xff, 0xbf, 0xff, 0xbf, 0xfd, 0xff, 0xff, 0xff, 0xff, 0x7f,
    0xff, 0xdf, 0xfe, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfd, 0xfe, 0xff, 0xff, 0xfb, 0x7f, 0xf7, 0xff, 0xf7, 0xff, 0xef, 0xff,
    0xdf, 0xfb, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xbf, 0xff, 0x7f, 0xfd, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfd,
    0xff, 0xff, 0xff, 0xeb, 0xff, 0xf7, 0xfe, 0xff, 0xff, 0xef, 0x7f, 0xdf, 0xff, 0xf7, 0xff, 0xbf, 0xff, 0xff, 0xfb, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xfe, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xdf, 0xf7, 0xff, 0xff, 0xff,
    0xef, 0xff, 0xdf, 0xfe, 0xff, 0xff, 0xbf, 0x7f, 0xff, 0xff, 0xf7, 0xff, 0x7f, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xbf, 0xff, 0xff, 0xf9, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xdf, 0xdf, 0xff, 0xff, 0xff, 0xaf, 0xff, 0xff,
    0xfe, 0xff, 0xff, 0x7f, 0x7f, 0xff, 0xfe, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xbf,
    0xff, 0xff, 0xed, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xdf, 0xff, 0xff, 0xff, 0xff, 0x6f, 0xff, 0xff, 0xfe, 0xff, 0xff,
    0xff, 0x7f, 0xff, 0xfd, 0xf7, 0xff, 0xff, 0xfb, 0xff, 0xf3, 0xff, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xbf, 0xff, 0xff, 0xbd,
    0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xdf, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0x7b, 0xff,
    0xf7, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xdb, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0x7d, 0xff, 0xff, 0xfe,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xfd, 0xff, 0xff, 0xef, 0xfb, 0xff, 0xf6, 0xff, 0xff, 0xff, 0x6f, 0xff, 0xdf, 0xf7, 0xff,
    0xff, 0xbf, 0xff, 0xfb, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xbe, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff,
    0xdb, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xef, 0xff, 0xde, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff,
    0xfb, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbd, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xcf, 0xff, 0xdf,
    0xff, 0xff, 0xef, 0xbf, 0xff, 0xfe, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xf6, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfd, 0xff,
    0xff, 0xff, 0xfb, 0xff, 0xb7, 0xff, 0xff, 0xfd, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xff, 0xff, 0xef,
    0x7f, 0xff, 0xfe, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xf5, 0xff, 0xff, 0xff, 0xfb, 0xfb, 0xf7, 0xff, 0xff, 0xff, 0xef,
    0xff, 0x9f, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5f, 0xff, 0xff, 0xfe, 0xff, 0xef, 0xff, 0xff, 0xfe,
    0xfd, 0xff, 0xff, 0x7f, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xfb, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xbf, 0xff,
    0xff, 0xfd, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfd, 0xff, 0xef, 0xff, 0xfb, 0xfe, 0xf7, 0xff, 0xff,
    0x7f, 0xef, 0xff, 0xd7, 0xff, 0xff, 0xff, 0xbf, 0xfb, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xbf, 0xfe, 0xff, 0xfd, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xdf, 0xfb, 0xff, 0xf7, 0xff, 0xef, 0xff, 0xef, 0xfe, 0xdf, 0xff, 0xff, 0x7f, 0xbf, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0x7f, 0xfb, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xfd, 0xff, 0xfd, 0xff, 0xfb, 0xff, 0xf7,
    0xff, 0xff, 0xdf, 0xef, 0xff, 0xdf, 0xff, 0xef, 0xff, 0xbf, 0xfe, 0xff, 0xff, 0xff, 0x7f, 0x7f, 0xff, 0xf7, 0xfe, 0xff,
    0xff, 0xff, 0xfb, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xbf, 0xf7, 0xff, 0xfd, 0xff, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xdf,
    0xbf, 0xff, 0xff, 0xff, 0xef, 0xff, 0x7f, 0xfe, 0xff, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xf7, 0xfd, 0xff, 0xff, 0xff, 0xfb,
    0xff, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xbf, 0xdf, 0xff, 0xfd, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xdf, 0x7f, 0xff, 0xff,
    0xfe, 0xef, 0xff, 0xff, 0xfe, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xfb, 0xf7, 0xf7, 0xff, 0xff, 0xff, 0xeb, 0xff, 0xdf, 0xff,
    0xff, 0xff, 0xbf, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfd, 0xef, 0xff,
    0xff, 0xfa, 0xff, 0xf7, 0xff, 0x7f, 0xff, 0xef, 0xf7, 0xdf, 0xff, 0xff, 0xff, 0xbb, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f,
    0xbf, 0xff, 0xfe, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xdf, 0xff, 0xfb, 0xff, 0xf7, 0xef, 0xff, 0xff, 0xee, 0xff,
    0xdf, 0xff, 0x7f, 0xff, 0xbf, 0xf7, 0xff, 0xff, 0xff, 0xff, 0x7b, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xfd,
    0xfd, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xff, 0xdf, 0xff, 0xef, 0xff, 0xdf, 0xef, 0xff, 0xff, 0xbe, 0xff, 0xff, 0xff, 0x7f,
    0xff, 0x7f, 0xf7, 0xff, 0xfe, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xbb, 0xff, 0xf7, 0xfd, 0xff, 0xff,
    0xef, 0xff, 0xdf, 0xff, 0xdf, 0xff, 0xbf, 0xff, 0xff, 0xef, 0xff, 0xff, 0x7e, 0xff, 0xff, 0xfe, 0x7f, 0xff, 0xff, 0xf7,
    0xff, 0xfd, 0xff, 0xff, 0xfb, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xaf, 0xff, 0xdf, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xdf, 0xff, 0x7f, 0xff, 0xff, 0xee, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfd, 0x7f, 0xff, 0xff, 0xf3, 0xff, 0xf7, 0xff,
    0xff, 0xfb, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xdf, 0xff,
    0xff, 0xff, 0xff, 0xed, 0xff, 0xff, 0xfe, 0xfb, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xe7, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xdf, 0xff, 0xff, 0xfb, 0xff,
    0xe7, 0xff, 0xff, 0xfe, 0xef, 0xff, 0xdf, 0x7f, 0xff, 0xff, 0xb7, 0xff, 0xff, 0xff, 0xff, 0xfb, 0x7f, 0xff, 0xff, 0xfe,
    0xff, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xdf, 0xff, 0xff, 0xef, 0xff, 0xcf, 0xff, 0xff,
    0xfe, 0xbf, 0xff, 0xff, 0x7f, 0xff, 0xff, 0x77, 0xff, 0xff, 0xfe, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf,
    0xfb, 0xff, 0xf5, 0xff, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xef, 0xff, 0xff, 0xfe, 0x7f, 0xff,
    0xff, 0x7e, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfd, 0xff, 0xfb, 0xff, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xbf, 0xef, 0xff, 0xdd,
    0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0x7f, 0xff, 0xef, 0xfe, 0xff, 0xfe, 0xff, 0xff, 0xff, 0x7d, 0xff,
    0xff, 0xf7, 0xfb, 0xff, 0xf7, 0xff, 0xfb, 0xff, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xbf, 0xff, 0xfd, 0xff, 0xff, 0xff,
    0x7f, 0xff, 0xff, 0xde, 0xff, 0xff, 0xff, 0xff, 0xef, 0xfd, 0xff, 0xfe, 0xff, 0xfb, 0xff, 0x77, 0xff, 0xff, 0xf7, 0xef,
    0xff, 0xdf, 0xff, 0xfb, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xbf, 0x7f, 0xff, 0xfd, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xdd, 0xff, 0xff, 0xff, 0xfb, 0xef, 0xf7, 0xff, 0xfe, 0xff, 0xef, 0xff, 0x5f, 0xff, 0xff, 0xf7, 0xbf, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xd7, 0xff, 0xff,
    0xff, 0xef, 0xef, 0xdf, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0x7f, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xfe, 0xfb, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xbf, 0xff, 0xfb, 0xfd, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xef,
    0xff, 0xff, 0xfe, 0xff, 0x7f, 0xff, 0x7f, 0xfe, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xff, 0xfb, 0xff, 0xf7,
    0xff, 0xbf, 0xff, 0xef, 0xfd, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xdf, 0xff, 0xff, 0xff, 0x7f, 0xef, 0xff, 0xfe, 0xfe,
    0xff, 0xff, 0xff, 0x7f, 0xfd, 0xff, 0xf7, 0xff, 0xfb, 0xff, 0xf7, 0xfb, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xff, 0xbf, 0xff,
    0xbf, 0xfd, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xdf, 0xfe, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfd, 0xfe, 0xff, 0xff, 0xfb,
    0x7f, 0xf7, 0xff, 0xf7, 0xff, 0xef, 0xff, 0xdf, 0xfb, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xbf, 0xff, 0x7f, 0xfd, 0xff,
    0xfe, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfd, 0xff, 0xff, 0xff, 0xeb, 0xff, 0xf7, 0xfe, 0xff, 0xff, 0xef, 0x7f, 0xdf, 0xff,
    0xf7, 0xff, 0xbf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xfd, 0xff, 0xff,
    0xff, 0xfb, 0xdf, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xfe, 0xff, 0xff, 0xbf, 0x7f, 0xff, 0xff, 0xf7, 0xff, 0x7f,
    0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xf9, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xdf,
    0xdf, 0xff, 0xff, 0xff, 0xaf, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0x7f, 0xff, 0xfe, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xf9,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xbf, 0xff, 0xff, 0xed, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xdf, 0xff, 0xff, 0xff,
    0xff, 0x6f, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xfd, 0xf7, 0xff, 0xff, 0xfb, 0xff, 0xf3, 0xff, 0xff, 0xff,
    0xef, 0xff, 0xdf, 0xbf, 0xff, 0xff, 0xbd, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xdf, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xfc, 0xff, 0xff, 0xff, 0x7b, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xdb, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0x7d, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfd, 0xff, 0xff, 0xef, 0xfb, 0xff, 0xf6, 0xff,
    0xff, 0xff, 0x6f, 0xff, 0xdf, 0xf7, 0xff, 0xff, 0xbf, 0xff, 0xfb, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xbe, 0xff, 0xff,
    0xfd, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xdb, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xef, 0xff, 0xde, 0xff, 0xff, 0xff, 0x3f,
    0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xfb, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbd, 0xff, 0xff, 0xfd, 0xfb, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0xcf, 0xff, 0xdf, 0xff, 0xff, 0xef, 0xbf, 0xff, 0xfe, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xf6,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xb7, 0xff, 0xff, 0xfd, 0xef, 0xff, 0xdf, 0xff, 0xff,
    0xff, 0x9f, 0xff, 0xff, 0xff, 0xff, 0xef, 0x7f, 0xff, 0xfe, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xf5, 0xff, 0xff, 0xff,
    0xfb, 0xfb, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xff, 0x9f, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5f, 0xff,
    0xff, 0xfe, 0xff, 0xef, 0xff, 0xff, 0xfe, 0xfd, 0xff, 0xff, 0x7f, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xfb, 0xdf,
    0xff, 0xff, 0xff, 0xbf, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfd, 0xff,
    0xef, 0xff, 0xfb, 0xfe, 0xf7, 0xff, 0xff, 0x7f, 0xef, 0xff, 0xd7, 0xff, 0xff, 0xff, 0xbf, 0xfb, 0xff, 0xff, 0xff, 0xff,
    0x7f, 0xff, 0xbf, 0xfe, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xdf, 0xfb, 0xff, 0xf7, 0xff, 0xef, 0xff, 0xef,
    0xfe, 0xdf, 0xff, 0xff, 0x7f, 0xbf, 0xff, 0xf7, 0xff, 0xff, 0xff, 0x7f, 0xfb, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbf,
    0xfd, 0xff, 0xfd, 0xff, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xdf, 0xef, 0xff, 0xdf, 0xff, 0xef, 0xff, 0xbf, 0xfe, 0xff, 0xff,
    0xff, 0x7f, 0x7f, 0xff, 0xf7, 0xfe, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xbf, 0xf7, 0xff, 0xfd,
    0xff, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xdf, 0xbf, 0xff, 0xff, 0xff, 0xef, 0xff, 0x7f, 0xfe, 0xff, 0xfe, 0xff, 0x7f, 0xff,
    0xff, 0xf7, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xbf, 0xdf, 0xff, 0xfd, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xff, 0xdf, 0x7f, 0xff, 0xff, 0xfe, 0xef, 0xff, 0xff, 0xfe, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xfb, 0xf7, 0xf7,
    0xff, 0xff, 0xff, 0xeb, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff,
    0xdf, 0xff, 0xff, 0xff, 0xfd, 0xef, 0xff, 0xff, 0xfa, 0xff, 0xf7, 0xff, 0x7f, 0xff, 0xef, 0xf7, 0xdf, 0xff, 0xff, 0xff,
    0xbb, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xbf, 0xff, 0xfe, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xdf, 0xff, 0xfb,
    0xff, 0xf7, 0xef, 0xff, 0xff, 0xee, 0xff, 0xdf, 0xff, 0x7f, 0xff, 0xbf, 0xf7, 0xff, 0xff, 0xff, 0xff, 0x7b, 0xff, 0xff,
    0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xff, 0xdf, 0xff, 0xef, 0xff, 0xdf, 0xef,
    0xff, 0xff, 0xbe, 0xff, 0xff, 0xff, 0x7f, 0xff, 0x7f, 0xf7, 0xff, 0xfe, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff,
    0xff, 0xbb, 0xff, 0xf7, 0xfd, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xff, 0xdf, 0xff, 0xbf, 0xff, 0xff, 0xef, 0xff, 0xff, 0x7e,
    0xff, 0xff, 0xfe, 0x7f, 0xff, 0xff, 0xf7, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xaf, 0xff,
    0xdf, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0x7f, 0xff, 0xff, 0xee, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfd,
    0x7f, 0xff, 0xff, 0xf3, 0xff, 0xf7, 0xff, 0xff, 0xfb, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xfe, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xed, 0xff, 0xff, 0xfe, 0xfb, 0xff, 0xf7, 0x7f, 0xff, 0xff,
    0xe7, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xe7, 0xff, 0xff, 0xfe, 0xef, 0xff, 0xdf, 0x7f, 0xff, 0xff, 0xb7, 0xff, 0xff,
    0xff, 0xff, 0xfb, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xdf,
    0xff, 0xff, 0xef, 0xff, 0xcf, 0xff, 0xff, 0xfe, 0xbf, 0xff, 0xff, 0x7f, 0xff, 0xff, 0x77, 0xff, 0xff, 0xfe, 0xff, 0xfb,
    0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xfb, 0xff, 0xf5, 0xff, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xdf, 0xff, 0xff, 0xbf,
    0xff, 0xef, 0xff, 0xff, 0xfe, 0x7f, 0xff, 0xff, 0x7e, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfd, 0xff, 0xfb, 0xff, 0xfb, 0xff,
    0xf7, 0xff, 0xff, 0xbf, 0xef, 0xff, 0xdd, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0x7f, 0xff, 0xef, 0xfe,
    0xff, 0xfe, 0xff, 0xff, 0xff, 0x7d, 0xff, 0xff, 0xf7, 0xfb, 0xff, 0xf7, 0xff, 0xfb, 0xff, 0xef, 0xff, 0xdf, 0xff, 0xff,
    0xbf, 0xbf, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xde, 0xff, 0xff, 0xff, 0xff, 0xef, 0xfd, 0xff, 0xfe, 0xff,
    0xfb, 0xff, 0x77, 0xff, 0xff, 0xf7, 0xef, 0xff, 0xdf, 0xff, 0xfb, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xbf, 0x7f, 0xff,
    0xfd, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xff, 0xfb, 0xef, 0xf7, 0xff, 0xfe, 0xff, 0xef, 0xff, 0x5f,
    0xff, 0xff, 0xf7, 0xbf, 0xff, 0xff, 0xff, 0xfb, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xfd, 0xff,
    0xff, 0xff, 0xfb, 0xff, 0xd7, 0xff, 0xff, 0xff, 0xef, 0xef, 0xdf, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0x7f, 0xff, 0xff, 0xf7,
    0x7f, 0xff, 0xff, 0xfe, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xbf, 0xff, 0xfb, 0xfd, 0xf7, 0xff, 0xff, 0xff, 0xef,
    0xff, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xef, 0xff, 0xff, 0xfe, 0xff, 0x7f, 0xff, 0x7f, 0xfe, 0xff, 0xf7, 0xff, 0xff, 0xff,
    0xfd, 0xfb, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xff, 0xbf, 0xff, 0xef, 0xfd, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xdf, 0xff,
    0xff, 0xff, 0x7f, 0xef, 0xff, 0xfe, 0xfe, 0xff, 0xff, 0xff, 0x7f, 0xfd, 0xff, 0xf7, 0xff, 0xfb, 0xff, 0xf7, 0xfb, 0xff,
    0xff, 0xef, 0xff, 0xdf, 0xff, 0xbf, 0xff, 0xbf, 0xfd, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xdf, 0xfe, 0xff, 0xff, 0xff,
    0xef, 0xff, 0xfd, 0xfe, 0xff, 0xff, 0xfb, 0x7f, 0xf7, 0xff, 0xf7, 0xff, 0xef, 0xff, 0xdf, 0xfb, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xbf, 0xff, 0x7f, 0xfd, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfd, 0xff, 0xff, 0xff, 0xeb, 0xff, 0xf7,
    0xfe, 0xff, 0xff, 0xef, 0x7f, 0xdf, 0xff, 0xf7, 0xff, 0xbf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xbf,
    0xff, 0xff, 0xfd, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xdf, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xfe, 0xff, 0xff,
    0xbf, 0x7f, 0xff, 0xff, 0xf7, 0xff, 0x7f, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xf9,
    0xff, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xdf, 0xdf, 0xff, 0xff, 0xff, 0xaf, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0x7f, 0xff,
    0xfe, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xbf, 0xff, 0xff, 0xed, 0xff, 0xdf, 0xff,
    0xff, 0xff, 0xbf, 0xdf, 0xff, 0xff, 0xff, 0xff, 0x6f, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xfd, 0xf7, 0xff,
    0xff, 0xfb, 0xff, 0xf3, 0xff, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xbf, 0xff, 0xff, 0xbd, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f,
    0xdf, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0x7b, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xef, 0xff,
    0xdb, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0x7d, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfd,
    0xff, 0xff, 0xef, 0xfb, 0xff, 0xf6, 0xff, 0xff, 0xff, 0x6f, 0xff, 0xdf, 0xf7, 0xff, 0xff, 0xbf, 0xff, 0xfb, 0xff, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xbe, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xdb, 0xff, 0xf7, 0xff, 0xff, 0xef,
    0xef, 0xff, 0xde, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xfb, 0xfe, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xbd, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xcf, 0xff, 0xdf, 0xff, 0xff, 0xef, 0xbf, 0xff, 0xfe,
    0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xf6, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xb7, 0xff,
    0xff, 0xfd, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xff, 0xff, 0xef, 0x7f, 0xff, 0xfe, 0xfe, 0xff, 0xff,
    0x7f, 0xff, 0xff, 0xf5, 0xff, 0xff, 0xff, 0xfb, 0xfb, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xff, 0x9f, 0xff, 0xff, 0xfd, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0x5f, 0xff, 0xff, 0xfe, 0xff, 0xef, 0xff, 0xff, 0xfe, 0xfd, 0xff, 0xff, 0x7f, 0xfb, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0xef, 0xfb, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0x7f, 0xff, 0xff, 0xfe,
    0xff, 0xff, 0xdf, 0xff, 0xff, 0xfd, 0xff, 0xef, 0xff, 0xfb, 0xfe, 0xf7, 0xff, 0xff, 0x7f, 0xef, 0xff, 0xd7, 0xff, 0xff,
    0xff, 0xbf, 0xfb, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xbf, 0xfe, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xdf,
    0xfb, 0xff, 0xf7, 0xff, 0xef, 0xff, 0xef, 0xfe, 0xdf, 0xff, 0xff, 0x7f, 0xbf, 0xff, 0xf7, 0xff, 0xff, 0xff, 0x7f, 0xfb,
    0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xfd, 0xff, 0xfd, 0xff, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xdf, 0xef, 0xff, 0xdf,
    0xff, 0xef, 0xff, 0xbf, 0xfe, 0xff, 0xff, 0xff, 0x7f, 0x7f, 0xff, 0xf7, 0xfe, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfd, 0xff,
    0xff, 0xff, 0xfb, 0xbf, 0xf7, 0xff, 0xfd, 0xff, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xdf, 0xbf, 0xff, 0xff, 0xff, 0xef, 0xff,
    0x7f, 0xfe, 0xff, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xf7, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xef,
    0xbf, 0xdf, 0xff, 0xfd, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xdf, 0x7f, 0xff, 0xff, 0xfe, 0xef, 0xff, 0xff, 0xfe, 0xff,
    0xfd, 0xff, 0x7f, 0xff, 0xfb, 0xf7, 0xf7, 0xff, 0xff, 0xff, 0xeb, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xbf, 0xff, 0xff,
    0xfd, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfd, 0xef, 0xff, 0xff, 0xfa, 0xff, 0xf7, 0xff, 0x7f,
    0xff, 0xef, 0xf7, 0xdf, 0xff, 0xff, 0xff, 0xbb, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xbf, 0xff, 0xfe, 0xfd, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xdf, 0xff, 0xfb, 0xff, 0xf7, 0xef, 0xff, 0xff, 0xee, 0xff, 0xdf, 0xff, 0x7f, 0xff, 0xbf, 0xf7,
    0xff, 0xff, 0xff, 0xff, 0x7b, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xf7,
    0xff, 0xdf, 0xff, 0xef, 0xff, 0xdf, 0xef, 0xff, 0xff, 0xbe, 0xff, 0xff, 0xff, 0x7f, 0xff, 0x7f, 0xf7, 0xff, 0xfe, 0xff,
    0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xbb, 0xff, 0xf7, 0xfd, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xff, 0xdf, 0xff,
    0xbf, 0xff, 0xff, 0xef, 0xff, 0xff, 0x7e, 0xff, 0xff, 0xfe, 0x7f, 0xff, 0xff, 0xf7, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xfb,
    0xff, 0xf7, 0xff, 0xff, 0xff, 0xaf, 0xff, 0xdf, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0x7f, 0xff, 0xff,
    0xee, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfd, 0x7f, 0xff, 0xff, 0xf3, 0xff, 0xf7, 0xff, 0xff, 0xfb, 0xef, 0xff, 0xdf, 0xff,
    0xff, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xed, 0xff, 0xff,
    0xfe, 0xfb, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xe7, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f,
    0xff },
  { 0xff, 0xf3, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbe, 0xff, 0xbf, 0xdf, 0xff,
    0xff, 0xff, 0xff, 0xfd, 0xfb, 0x7f, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf,
    0xff, 0xef, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff,
    0xff, 0xdf, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xfb, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfe, 0xff, 0xbf,
    0xff, 0xbf, 0xff, 0xff, 0xdf, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xf5, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfe,
    0xbf, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xdf, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xf7, 0xff, 0xfd, 0xff, 0xff, 0xff,
    0xff, 0x7f, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xbf, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbd, 0xff, 0x7f, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xfb, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xff, 0xdf, 0x7f, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xef, 0xff, 0xf7, 0xff, 0xff, 0xff,
    0xfe, 0xff, 0xbf, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfd, 0xff, 0x3f, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfb,
    0xff, 0xff, 0xfd, 0xff, 0xdf, 0xff, 0xff, 0x7b, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xef, 0xff, 0xff, 0xf7,
    0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfd, 0xff, 0x7f, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xf7, 0xff, 0xff,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xfb, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xef,
    0xff, 0xff, 0xf6, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfe, 0x7f, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xf7, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xdf, 0xff, 0xfd, 0xfb, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xef, 0xfe, 0xff, 0xb7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xb7,
    0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfb, 0xff, 0xfb, 0xfd, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xef, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xef, 0xbf, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xff,
    0xf7, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0x6f,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff,
    0xfe, 0xf7, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff,
    0xef, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf5, 0xff, 0x7f, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xf7, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xdf, 0xdf, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xfd, 0xef, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xef, 0xfd, 0xff, 0x77, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xdb, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0xef, 0xfd, 0xff, 0xff, 0xff, 0xff, 0x7e, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xef, 0x7f, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xdf, 0xff, 0xbf, 0xfb, 0xff, 0xdf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xeb, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfe, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0x7f,
    0xef, 0xff, 0xff, 0xf7, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xdf, 0xff, 0xff, 0xfb, 0xbf, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xfe, 0xff, 0xbf, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0x7f, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfe, 0xff, 0xfb, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0xdf, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfe, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xfd,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xef, 0xf7, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfa, 0xff,
    0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xcf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xbf, 0xfd, 0xff, 0xff, 0xff, 0xff,
    0x7d, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfb,
    0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xbb, 0xff, 0xff, 0xfd, 0xff,
    0xff, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xdf, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xef, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xfb, 0xff,
    0xff, 0xfd, 0xfd, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xd7, 0xff,
    0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xef, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xde, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xfb, 0xff, 0xfd, 0xfd, 0x7f, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xdf,
    0xff, 0xf7, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xee, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xfe, 0xff, 0x9f, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xf9, 0xff, 0x7f, 0xfd, 0xff, 0xff, 0xff, 0xff, 0x77, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xef, 0xff, 0xfb, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xfe, 0xbf, 0xbf,
    0xff, 0xdf, 0xff, 0xff, 0xff, 0xfd, 0xff, 0x7b, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xf7, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xdf, 0xff, 0xff, 0xeb, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xfe, 0xff,
    0xbf, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xf7, 0xff, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdd, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xfd, 0xff, 0xff, 0xff,
    0xff, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xfe, 0xff, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xfd, 0xff, 0x5f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf3, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xff, 0xff, 0x5f, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xef, 0xf7, 0xff, 0xff, 0xff,
    0xff, 0xfe, 0xff, 0xbf, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfb,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xdf, 0xff, 0x7f, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xfd, 0xff, 0x7f, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xf7, 0xff,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xdf, 0xff, 0xff, 0xfb, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xef,
    0xff, 0xff, 0xf7, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0x7f, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xd7,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xdf, 0xfd, 0xff, 0xfb, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xff, 0xef, 0xff, 0xfe, 0xf7, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0x7e, 0xff, 0xff, 0xff, 0xff, 0xbf,
    0xf7, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdb, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xef,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xee, 0xff, 0xbf, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xfe, 0xff, 0xff,
    0xff, 0xf7, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfb, 0xfb, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0x7f,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xaf, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0xff,
    0xfe, 0xff, 0xf7, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff,
    0xff, 0xef, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xfd, 0xff, 0x7f, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xf6, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xfd, 0xff, 0xef, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfd, 0xf7, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xdf, 0xff, 0xdf, 0xfb, 0xff, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xed, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xed, 0xff, 0x7f,
    0xf7, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xdf, 0xbf, 0xff, 0xfb, 0xdf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfb, 0xef, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xfe, 0x7f, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0x6f, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xdf, 0xff, 0xff, 0xbb, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xff, 0xff, 0xef, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xfe, 0xff, 0xbf, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0x7f, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xde, 0xff, 0xff, 0xfb, 0xff,
    0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfc, 0xff, 0xbf, 0xff, 0xff, 0x7f, 0xff, 0xff,
    0xfd, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xef, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfe, 0xfb,
    0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfe, 0xff, 0xbd, 0xff, 0xff, 0xff, 0xff,
    0x7f, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff,
    0xfb, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xef, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfb, 0xbf, 0xff, 0xfd, 0xff,
    0xff, 0xff, 0xfd, 0x7f, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xdf, 0xff,
    0xff, 0xfb, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xaf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xfb, 0xff,
    0xff, 0xfd, 0xff, 0xfd, 0xff, 0x7f, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xdf,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xfe, 0xff, 0xbf, 0xff,
    0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xdf, 0xf7, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xef, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xfe, 0xdf, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0x7d, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xcf, 0xff, 0xff, 0xf3, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbe, 0xff,
    0xbf, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfb, 0x7f, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xdf, 0xff, 0xef, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfe,
    0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0xfe, 0xff, 0xbf, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xf5, 0xff, 0xff, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfe, 0xfe, 0xbf, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xdf, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xf7, 0xff, 0xfd,
    0xff, 0xff, 0xff, 0xff, 0x7f, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xbf, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbd, 0xff, 0x7f, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xfb,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xdf, 0x7f, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xef, 0xff, 0xf7,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfd, 0xff, 0x3f, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xdf, 0xff, 0xff, 0x7b, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xef,
    0xff, 0xff, 0xf7, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfd, 0xff, 0x7f, 0xff, 0xbf, 0xff, 0xff, 0xdf,
    0xf7, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xfb, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef,
    0xff, 0xff, 0xef, 0xff, 0xff, 0xf6, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfe, 0x7f, 0xff, 0xff, 0xff, 0xbf,
    0xff, 0xf7, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xdf, 0xff, 0xfd, 0xfb, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xef, 0xfe, 0xff, 0xb7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xfe, 0xff, 0xff,
    0xff, 0xff, 0xb7, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfb, 0xff, 0xfb, 0xfd, 0xff, 0xff, 0xff, 0xff, 0x7f,
    0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xef, 0xbf, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xff,
    0xfe, 0xff, 0xff, 0xf7, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff,
    0xff, 0xff, 0x6f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xfd, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xf7, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xfb, 0xff, 0xff,
    0xfd, 0xff, 0xff, 0xef, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf5, 0xff, 0x7f,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xdf, 0xdf, 0xff, 0xfb, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xfd, 0xef, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xef, 0xfd, 0xff,
    0x77, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xdb, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xef, 0xfd, 0xff, 0xff, 0xff, 0xff, 0x7e, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xef, 0x7f, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xdf, 0xff, 0xbf, 0xfb, 0xff,
    0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xeb, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfe, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xfd, 0xff, 0x7f, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xdf, 0xff, 0xff, 0xfb,
    0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xfe, 0xff, 0xbf, 0xff, 0x7f, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfe, 0xff,
    0xfb, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfe, 0xfd, 0xbf, 0xff, 0xff, 0xff,
    0x7f, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xef, 0xf7, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff,
    0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xcf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xbf, 0xfd, 0xff,
    0xff, 0xff, 0xff, 0x7d, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xfb, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xbb, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xff,
    0xdf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xef, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xfe, 0xff, 0xbf,
    0xff, 0xfb, 0xff, 0xff, 0xfd, 0xfd, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xd7, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xef, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xde, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfd, 0xfd, 0x7f, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xdf, 0xff, 0xf7, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xee, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xfe,
    0xff, 0x9f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xff, 0x7f, 0xfd, 0xff, 0xff, 0xff, 0xff, 0x77, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xdf, 0xef, 0xff, 0xfb, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfe, 0xff, 0xff, 0xff,
    0xfe, 0xbf, 0xbf, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfd, 0xff, 0x7b, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xf7, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xeb, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xfe, 0xff, 0xbf, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xf7, 0xff, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdd, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xfd,
    0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xfd, 0xff, 0x5f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf3,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0x5f, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xef, 0xf7,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xff,
    0xf7, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xdf, 0xff, 0x7f, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef,
    0xff, 0xff, 0xf7, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xfd, 0xff, 0x7f, 0xbf, 0xff, 0xff, 0xdf,
    0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xdf, 0xff, 0xff, 0xfb, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xef, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0x7f, 0xff, 0xff, 0xbf,
    0xff, 0xff, 0xd7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xdf, 0xfd, 0xff, 0xfb, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfe, 0xf7, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0x7e, 0xff, 0xff,
    0xff, 0xff, 0xbf, 0xf7, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdb, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xff, 0xff, 0x7f,
    0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xee, 0xff, 0xbf, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xff,
    0xfe, 0xff, 0xff, 0xff, 0xf7, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfb, 0xfb, 0xff, 0xfd, 0xff, 0xff,
    0xff, 0xff, 0x7f, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xaf, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfd, 0xff, 0x7f,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xf7, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xfb, 0xff, 0xff,
    0xfd, 0xff, 0xff, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xfd, 0xff,
    0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf6, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xfd, 0xff, 0xef, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfd,
    0xf7, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xdf, 0xff, 0xdf, 0xfb, 0xff,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xed, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xed, 0xff, 0x7f, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xdf, 0xbf, 0xff, 0xfb,
    0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xef, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xfe, 0x7f, 0xbf, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0x6f, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xdf, 0xff, 0xff,
    0xbb, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xef, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xfe, 0xff, 0xbf, 0x7f, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xde, 0xff,
    0xff, 0xfb, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfc, 0xff, 0xbf, 0xff, 0xff,
    0x7f, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xef, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf,
    0xff, 0xfe, 0xfb, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfe, 0xff, 0xbd, 0xff,
    0xff, 0xff, 0xff, 0x7f, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xfb, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xef, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfb, 0xbf,
    0xff, 0xfd, 0xff, 0xff, 0xff, 0xfd, 0x7f, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xff,
    0xff, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xaf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfe, 0xff,
    0xbf, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xfd, 0xff, 0x7f, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xf7, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xfe,
    0xff, 0xbf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xff, 0xdf, 0xf7, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xef, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xfe, 0xdf, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0x7d, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xcf, 0xff },
  { 0xff, 0xaf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xf7,
    0xfb, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0x7f, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xdf, 0xff, 0x7f, 0xbf, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xdf, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0x7d, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfb, 0xff,
    0xdf, 0xff, 0xff, 0xbf, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xe7,
    0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfd, 0xff,
    0xbf, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xf7, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xee, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xf7, 0x7f, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xff, 0x6f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xdf, 0xff, 0xfd, 0xbf, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0xef, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xfd,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfe, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xeb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0x7f,
    0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfe, 0xfb, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0x9f, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7d, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff,
    0xff, 0xfe, 0xdf, 0xff, 0xef, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xf7, 0xfd, 0xff, 0xef, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff,
    0xfd, 0xff, 0xff, 0xf3, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xfe,
    0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff,
    0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfb, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd7, 0xff, 0xff, 0x3f,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xdf, 0xef, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xff, 0xff, 0xfb, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xfe, 0xff, 0xf7, 0xef, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xbb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff,
    0xfe, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xff, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff, 0x9f, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0x7f, 0xef,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0x7f, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xdf, 0xff, 0xfb, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xff, 0xed, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xfd, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xf7, 0x7f, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xef, 0xff, 0xff, 0xdf, 0xff,
    0xff, 0xbf, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xf7, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfd, 0x7f, 0xff, 0xfb,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xde, 0xff, 0xff, 0xaf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xde, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfd, 0xef, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfe, 0xff,
    0xff, 0xef, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xbf, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf,
    0xf7, 0xff, 0xbf, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xf7, 0xff,
    0xff, 0xcf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdb, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7e, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xf7, 0xff, 0xef, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0x7f, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfd, 0xfd, 0xff, 0xfb, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfb,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xfe, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0xdf, 0xbf, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0x6f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0x7f, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0xdf, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfe, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xfd, 0xef, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xfb, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0x77, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xfe, 0xff, 0xff, 0xef,
    0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff,
    0xb7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xfd,
    0xff, 0x7f, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfe, 0xff, 0xbf, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xed, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xdf, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xff, 0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xfb, 0xff, 0xff,
    0xff, 0xff, 0xdf, 0xff, 0xf7, 0xbf, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xf7, 0xff, 0xff, 0xef, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf,
    0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfb, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfe,
    0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf6, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff,
    0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfd, 0xfb, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xdf, 0xff, 0xbf, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xf7, 0xf7, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xdb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff,
    0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf3, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfd, 0xff, 0xef, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff,
    0xfe, 0xff, 0xff, 0xef, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xf7, 0xbf, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7b, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xf5, 0xff, 0xff, 0x7b, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfe, 0xbf, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xff, 0xfe, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x5f, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xfe, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xf7, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb,
    0xff, 0xfb, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xb7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xff, 0xef, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff,
    0xfd, 0xff, 0xff, 0xbd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfb, 0xbf, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xf7, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xfe, 0xff, 0xef, 0xef, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xdf, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xf7, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfd, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xf7, 0xef, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xfe, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xbf, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xfb, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0x7f, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xeb, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xdf, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xfd, 0xff,
    0xff, 0xfb, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xcf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfe, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xf7, 0xff, 0xbf, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xfb,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xf7, 0xff, 0xfb, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbe, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xfd, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7,
    0xff, 0xdf, 0x7f, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfe, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xd7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0x7f, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f,
    0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfd, 0xbf, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbb, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xf6, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfe, 0xef, 0xff, 0xef,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xff,
    0xbf, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff,
    0xff, 0x77, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf,
    0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfd, 0xff, 0xbf, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xe7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff,
    0x7f, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf,
    0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfb, 0xef, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfe, 0xff, 0xfb, 0xef, 0xff,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xdf, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf,
    0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xf7, 0xff, 0xff,
    0x7f, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xdf, 0xef, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff,
    0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf5, 0xff, 0xff, 0xaf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0x7f, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xf7, 0xfb, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff,
    0xbf, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xfb, 0xff,
    0xff, 0xff, 0xff, 0xf7, 0xdf, 0xff, 0x7f, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xf7, 0xdf, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7d, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xf7, 0xff, 0xff, 0x7f,
    0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfd, 0xff, 0xbf, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff,
    0xff, 0xbf, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff,
    0xee, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb,
    0xff, 0xfd, 0xff, 0xff, 0xbf, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xf7, 0xff, 0xf7, 0x7f, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x6f, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfd, 0xbf, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xf7, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfe, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff,
    0xff, 0xeb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0x7f, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfe,
    0xfb, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff,
    0xfd, 0xff, 0xff, 0xbf, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0x7f, 0xff, 0xff,
    0xff, 0xf7, 0xff, 0xff, 0x7d, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xdf, 0xff, 0xef, 0xbf, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xdf, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xfd, 0xff, 0xef, 0xbf, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xf3, 0xff, 0xff, 0x7f, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xbf, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0xfb, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd7, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfe, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xdf, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xfd,
    0xff, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0x7f, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xf7, 0xef, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xff, 0xdf, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbb, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfb,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0x7f, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0x7f,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xdf, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbd, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xf7,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xed, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xf7, 0xff, 0xff, 0xef, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff,
    0xfd, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff,
    0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfd, 0x7f, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xde, 0xff, 0xff, 0xaf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xde, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfd, 0xef, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xf7, 0xff,
    0xff, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xf7, 0xff, 0xbf, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xfe, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xcf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0x7f, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdb, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7e, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xf7, 0xff, 0xef, 0xef,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfd, 0xff, 0xfb, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xf7, 0xff, 0xff,
    0x7f, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xdf, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xdf, 0xbf, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfe, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x6f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfe, 0x7f, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xdf, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff,
    0xff, 0xbf, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xf7, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xfd, 0xef, 0xff, 0xfb,
    0xff, 0xff, 0xff, 0xff, 0xdf, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x77, 0xff, 0xff, 0x7f,
    0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xdf, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xb7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfb, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xfd, 0xff, 0x7f, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf,
    0xfe, 0xff, 0xbf, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff,
    0xff, 0xed, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfd, 0xff, 0xff,
    0xfb, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xee, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0x3f, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xf7, 0xbf, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xdf, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xfb, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfe, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf6,
    0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0xfd, 0xfb, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfe, 0xff, 0xff,
    0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xdf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xdf, 0xff, 0xbf, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0xef, 0x7f, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xdb, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xf3, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfd,
    0xff, 0xef, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfd,
    0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f,
    0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xdf, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xdf, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xf7, 0xbf, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7b, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf5, 0xff, 0xff, 0x7b, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xdf, 0xff, 0xfe, 0xbf, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xf7, 0xff, 0xff, 0xef, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb,
    0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x5f, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xfe,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0x7f, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xb7,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff,
    0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbd, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xfb, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xf7, 0xfe, 0xff, 0xef, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff,
    0xfe, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdd, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xf7, 0xef,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xf7, 0xfb, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0x7f, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfc, 0xff, 0xff, 0xeb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xdf, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfe, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xcf, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xf7, 0xff, 0xbf,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xf7, 0xff, 0xfb,
    0x7f, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xdf, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xdf, 0x7f, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfe, 0xfe, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0x7f, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xbf, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xf7, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfd, 0xbf, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf6, 0xff, 0xff, 0x7f,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfe, 0xef, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5f, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfb, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x77, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff,
    0xfe, 0xff, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xfd, 0xff, 0xbf, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xe7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xfd, 0xff,
    0xff, 0xfb, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbe, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfb, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfe, 0xff, 0xfb, 0xef, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xdf, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xff, 0xfb, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xdf, 0xef, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xf5, 0xff },
  { 0xff, 0x7f, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xdf, 0xfb, 0xff, 0xff, 0xef, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xef, 0xff, 0xff, 0xfb, 0xdf, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0x7f, 0xff,
    0x7f, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xfb, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xfb, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xff, 0xef, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xef, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff,
    0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xdf, 0xff,
    0xff, 0xff, 0xef, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xdf, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfd, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xfd, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfd,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xf7, 0xff, 0xff, 0xf7, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef,
    0xfd, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xbf, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef,
    0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xfb, 0xff, 0xff, 0xfb, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xbf, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xbf, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfb, 0xfb, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfd, 0xff, 0xff,
    0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfd, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xfd, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xdf, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xf7, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xf7, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfe, 0xdf, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xfe, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xf7, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xff, 0xf7, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xfe, 0xff, 0xff, 0x5f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5f, 0xff, 0xff, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xef, 0xff, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0x7f, 0xff, 0xef, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x6f, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0x6f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xf7, 0xff,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xff, 0xf7, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xf7, 0xfe, 0xff,
    0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff,
    0xff, 0xfe, 0xf7, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xbf, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xbf, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xf7, 0xff, 0xff, 0xfe,
    0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb,
    0xfe, 0xff, 0xff, 0x77, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x77, 0xff, 0xff, 0xff, 0xfb,
    0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0xfb, 0xff, 0x7f, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xbf, 0xff, 0xdf, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xdf, 0xff, 0xbf, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0x7f, 0xff, 0xfb, 0xff,
    0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff,
    0xff, 0x7b, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xaf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff,
    0xff, 0xdf, 0xff, 0xff, 0xff, 0xaf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0x7b, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfe, 0xff, 0xff,
    0x7f, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff,
    0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfe, 0xff, 0xff, 0x7f,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0x7f,
    0xff, 0xff, 0xff, 0xfd, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfd, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xff,
    0xdf, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff,
    0x7f, 0xff, 0xfd, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7d, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xb7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xcf, 0xff, 0xff,
    0xff, 0xcf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0x7d, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xfd, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xbf, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xef, 0xff,
    0xef, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xbf, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xfd, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xbb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xd7, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xff, 0xd7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xdf, 0xff, 0xf7, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xef, 0xff, 0xf7, 0xff, 0xdf, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xfe, 0xff, 0xff, 0x7e, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xbd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdb, 0xff, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xff, 0xdb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbd, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0xff, 0xff, 0x7f, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xbf, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfb, 0xff, 0xef, 0xff, 0xf7, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xf7, 0xff, 0xef, 0xff, 0xfb, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xbf, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0x7f, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xeb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff,
    0xff, 0xf7, 0xff, 0xff, 0xff, 0xeb, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfd, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xff,
    0xf7, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfd, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xbf, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xbe, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xed, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf3, 0xff, 0xff,
    0xff, 0xf3, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xed, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xbe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xbf, 0xff, 0xfe, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfb, 0xff,
    0xfb, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xfe, 0xff, 0xbf, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xbf, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb,
    0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xff, 0x7f, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0x7f, 0xff, 0xff, 0xff, 0xff,
    0xfe, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfe, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff,
    0xff, 0xde, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf5, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xff, 0xfb, 0xff, 0xff, 0xff, 0xf5, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xde, 0xff, 0xff,
    0x7f, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff,
    0xdf, 0xff, 0xfe, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfd, 0xff, 0xfb, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfb, 0xff, 0xfd, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfe, 0xff, 0xdf, 0x7f,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xdf,
    0xff, 0xff, 0xff, 0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xee, 0xff, 0xff, 0x7f, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0x7f,
    0xff, 0xff, 0xef, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfd, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xef, 0x7f, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff,
    0x7f, 0xef, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xef, 0xff, 0xff,
    0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff,
    0xef, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf6, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf6, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xef,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xf7, 0xff, 0xfe, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfe, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xdf, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xbf, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xbf, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xfb, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xfb, 0x7f, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xef, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xef, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xfb, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xbf, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xbf, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff,
    0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xdf, 0xdf, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfd, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xfd, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xdf, 0xff, 0xff, 0xdf, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xf7,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xfd, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xbf, 0xf7,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xef, 0xff, 0xff, 0xef, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xbf,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xbf, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xef, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff,
    0xbf, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff,
    0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xfb, 0xff, 0xff,
    0xff, 0xf7, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff,
    0xfb, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff,
    0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfb, 0xff,
    0xff, 0xff, 0xf7, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xf7, 0xff, 0xff, 0xff, 0xfb,
    0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfb,
    0xff, 0xff, 0xdf, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xdf, 0xff, 0xff, 0xfb, 0xff,
    0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff,
    0xfe, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xfb, 0xdf, 0xff, 0xff, 0xf7, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xf7, 0xff, 0xff, 0xdf, 0xfb, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xbf, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xfe, 0xff, 0xff,
    0x7f, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xfb, 0xff, 0xff, 0xef, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xef, 0xff, 0xff, 0xfb, 0xdf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0x7f, 0xff, 0x7f,
    0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xfb, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xfb, 0xff, 0xff, 0xdf, 0xff,
    0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xdf, 0xff,
    0xff, 0xff, 0xef, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xef, 0xff, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0x7f,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xdf, 0xff, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xdf, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff,
    0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfd, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xfd, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfd, 0xef,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xf7, 0xff, 0xff, 0xf7, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xfd,
    0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xbf, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xfd,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xfb, 0xff, 0xff, 0xfb, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xef,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xbf, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0x7f, 0xff, 0xbf, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xfd, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfb, 0xfb, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xbf, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xfd, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xdf, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xf7, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xf7, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfe, 0xdf, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xfe, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xf7, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xef, 0xfe, 0xff, 0xff, 0x5f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5f, 0xff, 0xff, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xef, 0xff, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0x7f, 0xff, 0xef, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x6f, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0x6f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xf7, 0xff,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xf7, 0xff, 0xff,
    0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff,
    0xf7, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xf7, 0xfe, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xfe, 0xf7, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xbf, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xf7, 0xff, 0xff, 0xfe, 0xfb,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfe,
    0xff, 0xff, 0x77, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0x9f, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x77, 0xff, 0xff, 0xff, 0xfb, 0xfe,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfb,
    0xff, 0x7f, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xbf, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xdf, 0xff, 0xbf, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0x7f, 0xff, 0xfb, 0xff, 0xff,
    0xfe, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff,
    0x7b, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xaf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xff, 0xaf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0x7b, 0xff, 0xff, 0xff,
    0xff, 0xfe, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f,
    0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xdf,
    0xff, 0xff, 0xff, 0xef, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0x7f, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfe, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff,
    0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xfd, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfd, 0xff, 0x7f, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xff, 0xdf,
    0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f,
    0xff, 0xfd, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7d, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xb7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xcf, 0xff, 0xff, 0xff,
    0xcf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0x7d, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xfd, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xbf, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xef, 0xff, 0xef,
    0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xbf, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xbb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xef,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff,
    0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xfd, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xd7, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xd7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xfe, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xdf, 0xff, 0xf7, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xff, 0xf7, 0xff, 0xdf, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xfe, 0xff, 0xff, 0x7e, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xbd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdb, 0xff, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xe7, 0xff, 0xff, 0xff, 0xdb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbd, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0xff, 0xff, 0x7f, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xbf, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfb, 0xff, 0xef, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xf7, 0xff, 0xef, 0xff, 0xfb, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0x7f, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xeb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0xeb, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xf7,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfd, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xff, 0xf7,
    0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfd, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf,
    0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xbe, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xed, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf3, 0xff, 0xff, 0xff,
    0xf3, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xed, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xbe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xbf, 0xff, 0xfe, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfb, 0xff, 0xfb,
    0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xbf, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xbf, 0xff, 0xff, 0xff, 0xfe, 0xff,
    0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff,
    0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfe, 0xff,
    0xff, 0x7f, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfb,
    0xff, 0xff, 0xff, 0xf7, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfe, 0xff, 0xff,
    0x7f, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff,
    0xde, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf5, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0xf5, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xde, 0xff, 0xff, 0x7f,
    0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xdf,
    0xff, 0xfe, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfd, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfb, 0xff, 0xfd, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfe, 0xff, 0xdf, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xdf, 0xff,
    0xff, 0xff, 0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xf9, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xee, 0xff, 0xff, 0x7f, 0xdf, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0x7f, 0xff,
    0xff, 0xef, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0x7f,
    0xef, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff,
    0xfd, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xef, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef,
    0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfd,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf6, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf6, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xf7, 0xff, 0xfe, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfd,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfe, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef,
    0xff, 0xff, 0xff, 0xdf, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff,
    0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xbf, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xbf, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xfb, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xfb, 0x7f, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xfb, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xbf, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfd, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xdf, 0xdf, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfd, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xfd, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xbf, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xdf, 0xff, 0xff, 0xdf, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xf7, 0xff,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xfd, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xbf, 0xf7, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xef, 0xff, 0xff, 0xef, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xbf, 0xff,
    0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xbf, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xef, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xbf,
    0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff,
    0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xfb, 0xff, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfb,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xfe,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xff, 0xf7, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xf7, 0xff, 0xff, 0xff, 0xfb, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff,
    0xff, 0xdf, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xff, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xfe,
    0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb,
    0xdf, 0xff, 0xff, 0xf7, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xf7, 0xff, 0xff, 0xdf, 0xfb, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xbf, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xfe, 0xff },
  { 0xff, 0xff, 0xf9, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xef, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfe, 0xff, 0xff, 0xfe, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff,
    0xfd, 0xff, 0xf7, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xdf, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfe, 0xff, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfb, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xbf, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xfb, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xdf, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xfe,
    0xff, 0xff, 0xff, 0xb7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xf7, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xdf, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf6, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfb,
    0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xf7, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xef,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff,
    0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x3f,
    0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xef, 0xff, 0xfb, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f,
    0xff, 0xff, 0xef, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfb, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbd, 0xff, 0xff, 0xff, 0x7f, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xdf, 0xff, 0xff, 0xff, 0xfe, 0xfb,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xfd, 0xfd, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xde, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff,
    0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff,
    0x7f, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xef, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xff, 0x7f, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x5f, 0xff, 0xff, 0xff, 0xff, 0xf3, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xfe, 0xff, 0xff, 0xfd,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xdf, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xdf, 0xf7,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf,
    0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfb, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xaf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff,
    0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xff,
    0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xfb, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xef,
    0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xef, 0xfd, 0xff, 0xff, 0xff, 0x7e, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xf7, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xde, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xef, 0xff, 0xff, 0xff,
    0xff, 0xfe, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xfb, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xef, 0xff, 0xff, 0xbf, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7d, 0xff, 0xff, 0xff,
    0x7f, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf3, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xbf, 0xdf, 0xff, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xdf, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfe, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfd, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfd, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xef, 0xef, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0x7f, 0xff, 0xbf,
    0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfb, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xf7, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff,
    0xff, 0xff, 0xdb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xee, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xfe, 0xff, 0xff, 0xf7, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff,
    0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xf7, 0xff, 0xfd, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xdf, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xfe, 0xff, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xff, 0xfd, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6f, 0xff,
    0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xbf, 0x7f, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xef, 0xff, 0xff, 0xfb, 0xff, 0xfe, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xef, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa,
    0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xfd, 0xff, 0xff, 0xff, 0x7d, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef,
    0xff, 0xdf, 0xff, 0xff, 0xfe, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xf7, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0x7f,
    0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f,
    0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0x7f, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xe7, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xdf, 0xff, 0xff, 0xff, 0xf7, 0xfb,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0xfe, 0xff, 0xfd, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xdf, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xf7, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0x7f, 0xff, 0xff, 0xff, 0xff, 0xd7, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff,
    0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xef, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0xef, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfb, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xed, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xdf,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfd, 0xff, 0xff, 0xfe, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xf7, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xdf, 0xff,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff,
    0xfe, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xbf, 0xff, 0xff, 0xff, 0xff,
    0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff,
    0xff, 0xff, 0xaf, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0x7f, 0x7f, 0xff, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xbf, 0xff, 0xff, 0xfb, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef,
    0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xee, 0xff, 0xff, 0xff, 0xbf, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0x7f, 0xfd, 0xff, 0xff, 0xff, 0x77, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xf7, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xdf, 0xff, 0xff, 0xfd, 0xff, 0xfb, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xfe, 0xfe, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf5, 0xff, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0x7f, 0xff, 0xff, 0xff,
    0xff, 0xf7, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff,
    0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xef, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0x7f, 0xff, 0xff, 0xbf, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xff,
    0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb7, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xdf, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xf7, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xf7, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0x7f, 0xff, 0xff,
    0xff, 0xff, 0xf7, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xeb, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0x7f, 0xef, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfb, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xbf, 0xff, 0x7f, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xef, 0xff,
    0xff, 0xff, 0xfb, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xfd, 0xff, 0xff, 0xfd, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xdf, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xfe, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xfb,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0x7f, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbe,
    0xff, 0xff, 0xff, 0xbf, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x5f, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xf7, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f,
    0xff, 0xdf, 0xff, 0xff, 0xf7, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xfe, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xf6, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfb, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xbf, 0xff, 0xef, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xdf, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xef, 0xff, 0xff, 0x7f, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0x77, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdb, 0xff, 0xff, 0xff, 0xff, 0xfb,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xdf, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfd, 0xff, 0xfe,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfb, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff,
    0xff, 0xbb, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xbf, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0x7f, 0xff, 0x7f, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xbf, 0xff, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xcf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xff,
    0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xfd, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff,
    0xfd, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff,
    0xf7, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xfe, 0xff,
    0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7b, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xef,
    0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0xff, 0xff, 0xff, 0xbf, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xf7, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xdf, 0xff, 0xfb, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff,
    0xfe, 0xf7, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xf5, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xdf, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xfb, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xfb, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xfb, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff,
    0x7f, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xcf, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff,
    0xff, 0xff, 0xf7, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xf7, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xfe, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfb, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfd, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0x7b, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xeb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xbf, 0xbf,
    0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xf7, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0x7f, 0xff,
    0xff, 0xff, 0xfb, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xfe, 0xff, 0xff, 0xff, 0xbd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xfd, 0xff, 0xff, 0xdf, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xf7, 0xff, 0xff, 0xfe, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xdf, 0xff, 0xf7, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xef,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x6f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f,
    0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xef, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xff, 0xff, 0xbf, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xed, 0xff, 0xff, 0xff, 0x7f, 0xfe, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xfb, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xfd, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff,
    0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f,
    0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xbf, 0xfb, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xef, 0xff, 0xbf, 0xff, 0xff, 0xfe,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0x7f, 0xff, 0xff, 0x7f, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xf7, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xff, 0xff, 0xf9,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xff, 0xfe, 0xff, 0xff, 0xfe, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfd, 0xff, 0xf7,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xdf, 0xfd, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff,
    0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff,
    0xfe, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0x7f, 0xbf, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xfb, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff,
    0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xfe, 0xff, 0xff, 0xff,
    0xb7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xbf, 0xff, 0xf7, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff,
    0xdf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf6, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xf7, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xfe, 0xff,
    0xff, 0xff, 0xbf, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xef, 0xff, 0xfb, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xef,
    0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfb, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xbd, 0xff, 0xff, 0xff, 0x7f, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff,
    0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xdf, 0xff, 0xff, 0xff, 0xfe, 0xfb, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xfd, 0xfd, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xd7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xde, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0x7f, 0xfb, 0xff,
    0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff,
    0x7f, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0x5f, 0xff, 0xff, 0xff, 0xff, 0xf3, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff,
    0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xfe, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xdf, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xf7, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xdf, 0xf7, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xff, 0xfd, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfd, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xaf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xef, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xf7, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfb,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xef, 0xfd, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0x9f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef,
    0xfd, 0xff, 0xff, 0xff, 0x7e, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xf7, 0xff, 0xff, 0xf7, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xde, 0xff, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0x7f,
    0xff, 0xff, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0xef, 0xff, 0xff, 0xbf, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7d, 0xff, 0xff, 0xff, 0x7f, 0xf7, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf3, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xbf, 0xdf, 0xff, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfe, 0xff, 0xfe, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0x7f, 0xff, 0xff, 0xff, 0xfd, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xf7, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xdd, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f,
    0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xef, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0x7f, 0xff, 0xbf, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfb, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xf7, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xdb,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0x7f, 0xff, 0xfe, 0xff, 0xff, 0xf7, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfd, 0xff, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xf7, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xdf, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff,
    0xfe, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff,
    0xfd, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff,
    0xff, 0xfb, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x6f, 0xff, 0xff, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xbf, 0x7f, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xef, 0xff, 0xff, 0xfb, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xef, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xfd, 0xff, 0xff, 0xff, 0x7d, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xdf, 0xff,
    0xff, 0xfe, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xf7, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0x7f, 0xff, 0xff, 0xff,
    0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff,
    0xff, 0xff, 0xbf, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff,
    0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0x7f, 0xff, 0xfb, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xef,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xe7, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xdf, 0xff, 0xff, 0xff, 0xf7, 0xfb, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff,
    0xfe, 0xff, 0xfd, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xdf, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xf7, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff,
    0xff, 0xff, 0xd7, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xdf, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xef, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xef, 0xff,
    0x7f, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xdf, 0xfb, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xff, 0xed, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xdf, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xfd, 0xff, 0xff, 0xfe, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff,
    0xff, 0xf7, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xdf, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xfd, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xaf,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0x7f, 0x7f, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xbf,
    0xff, 0xff, 0xfb, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xdf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xee, 0xff, 0xff, 0xff, 0xbf, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f,
    0xfd, 0xff, 0xff, 0xff, 0x77, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xdf, 0xff, 0xff, 0xfd, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfe, 0xfe, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf5, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xdf, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xef, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0x7f, 0xff, 0xff, 0xbf, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfb, 0xff, 0xff, 0x7f, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xb7, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xdf, 0xff, 0xff, 0xff, 0xdf, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xfe, 0xff, 0xf7, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfb, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xf7, 0xfd,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7,
    0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf,
    0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xeb, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0x7f, 0xef, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfb, 0xbf, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xbf, 0xff, 0x7f, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xef, 0xff, 0xff, 0xff, 0xfb,
    0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfb, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xfd, 0xff, 0xff,
    0xfd, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xef, 0xff, 0xff, 0xdf, 0xff, 0xfe, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff,
    0xf7, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xdf, 0xff, 0xff, 0xff,
    0xff, 0xfb, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xfb, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0x7f, 0xff, 0xff, 0xfb, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbe, 0xff, 0xff, 0xff,
    0xbf, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x5f, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xef, 0xf7, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xdf, 0xff,
    0xff, 0xf7, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xfe, 0xfd, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xdd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xf6, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xfe, 0xff,
    0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xff, 0xfb, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xef,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfd, 0xef, 0xff, 0xff, 0x7f, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x77, 0xff, 0xff,
    0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdb, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xfe, 0xff, 0xdf, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfd, 0xff, 0xfe, 0xff, 0x7f, 0xff,
    0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff,
    0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff,
    0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xef, 0xff,
    0xff, 0xff, 0xff, 0xfe, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xf7,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xbb, 0xff,
    0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfe, 0xff, 0xff, 0xef, 0xbf, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0x7f, 0xff,
    0x7f, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xdf, 0xbf, 0xff, 0xff, 0xff, 0xfb, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xcf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xfe, 0xff, 0xff, 0xff, 0xbe, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xfd, 0xff, 0xff, 0xf7, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb,
    0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0xff, 0xfd, 0xff, 0xff,
    0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xef,
    0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xfd, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf,
    0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0x3f,
    0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7b, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff,
    0xff, 0xff, 0xfb, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xef, 0xff, 0xfe, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7e, 0xff, 0xff, 0xff, 0xbf, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xf9, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xf7, 0xff, 0xff, 0xff, 0xfd, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xdf, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xfe, 0xf7, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff,
    0xbf, 0xff, 0xff, 0xff, 0xff, 0xf5, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff,
    0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xef, 0xfb, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xef, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe,
    0xff, 0xfb, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xbf, 0xff, 0xff, 0x7f, 0xff, 0xfd,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xcf, 0xff, 0xff, 0xff, 0xff, 0xfa, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7,
    0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xbf, 0xff, 0xff, 0xfd, 0xff, 0xfd, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xdf,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xdf, 0xfe, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff,
    0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff,
    0xfe, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0x7b, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xeb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xbf, 0xbf, 0xff, 0xff, 0xff,
    0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xf7, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0x7f, 0xff, 0xff, 0xff, 0xfb,
    0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xbf, 0xfe, 0xff, 0xff, 0xff, 0xbd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff,
    0xdf, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xf7, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0x7f, 0xff, 0xff, 0xdf, 0xff, 0xf7, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xbf, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff,
    0xff, 0xfe, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xdf, 0xff, 0xff, 0xff,
    0xff, 0xfb, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xbf, 0xff, 0xff, 0xff,
    0xff, 0xfd, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfd,
    0xff, 0xff, 0xff, 0x6f, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff,
    0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfb, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xef, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff,
    0xbf, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xed, 0xff, 0xff, 0xff, 0x7f, 0xfe, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0x7f, 0xf7, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xdf, 0xff,
    0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xdf, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff,
    0xff, 0xfd, 0xfe, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xbf, 0xff, 0xff,
    0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff, 0xfe, 0xff,
    0xff, 0xff, 0xbf, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0x7f, 0x7f, 0xff, 0xff,
    0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
    0xdf, 0xff, 0xff, 0xff, 0xbf, 0xfb, 0xff, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef,
    0xff, 0xff, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfe, 0xff, 0xef, 0xff, 0xbf, 0xff, 0xff, 0xfe, 0xff, 0xff, 0xff,
    0xff, 0xff, 0xff, 0xfd, 0x7f, 0xff, 0xff, 0x7f, 0xff, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xfb, 0xff,
    0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x9f, 0xff, 0xff }
}};

} // namespace

#endif
